<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://www.trustt.io/
 * @since      1.0.0
 *
 * @package    Trustt
 * @subpackage Trustt/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Trustt
 * @subpackage Trustt/admin
 * @author     Dimitri Longo <info@elanathemes.fr>
 */
class Trustt_Admin_Config {

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $trustt    The ID of this plugin.
     */
    private $trustt;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version
     */
    private $version;

    /**
	 * The version of json orders.
     *
     * @since    1.1.0
     * @access   private
     * @var      string    $version_json_orders
     */
    private $version_json_orders;

    /**
     * wp_options name for config tab.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $options_config    The name of option for config.
     */
    private $options_config;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string    $trustt
     * @param      string    $version
     */
    public function __construct( $trustt, $version, $version_json_orders, $options_config ) {

        $this->trustt              = $trustt;
        $this->version             = $version;
        $this->version_json_orders = $version_json_orders;
        $this->options_config      = $options_config;
        $this->is_admin            = is_admin();

        $this->ifdebug();

        add_action( 'admin_head', array( $this, 'el_admin_style' ) );

    }

    /**
     * Add style to admin
     *
     * @access public
     * @since  1.0
     * @return string
     */
    public function el_admin_style() {

        $currentScreen = get_current_screen();

        $screen = array( 'toplevel_page_el-trustt-config');

        if ( in_array($currentScreen->id, $screen)) {
            echo '<style>
            body {
                height: auto;
            }
            </style>';
        }
    }

    /**
     * Register plugin admin pages.
     * Render all Trustt trustt admin pages.
     *
     * @access public
     * @since  1.0
     * @return void
     */
    public function admin_menus() {

        add_menu_page(
            esc_html__( 'Trustt Reviews', 'trustt' ),
            esc_html__( 'Trustt Reviews', 'trustt' ),
            'manage_options',
            'el-trustt-config', array(
                $this,
                'el_welcome_screen'
            ),
            'dashicons-megaphone',
            '84'
        );

        add_submenu_page(
            'el-trustt-config',
            esc_html__( 'Général', 'trustt' ),
            esc_html__( 'Général', 'trustt' ),
            'manage_options',
            'el-trustt-general', array(
                $this,
                'el_general_screen'
            )
        );

        add_submenu_page(
            'el-trustt-config',
            esc_html__( 'Ecommerce', 'trustt' ),
            esc_html__( 'Ecommerce', 'trustt' ),
            'manage_options',
            'el-trustt-ecommerce', array(
                $this,
                'el_ecommerce_screen'
            )
        );

        add_submenu_page(
            'el-trustt-config',
            esc_html__( 'Commandes', 'trustt' ),
            esc_html__( 'Commandes', 'trustt' ),
            'manage_options',
            'el-trustt-orders', array(
                $this,
                'el_orders_screen'
            )
        );

    }

    /**
     *  Render Tabs
     *
     * @since    1.0.0
     */
    public function tabs() {
        $selected = isset ( $_GET['page'] ) ? $_GET['page'] : 'el-trustt-general';
        $currentScreen = get_current_screen();
        ?>
         <h2 class="nav-tab-wrapper">
            <a class="nav-tab <?php echo $selected == 'el-trustt-general' ? 'nav-tab-active' : ''; ?>"
                href="<?php echo esc_url( admin_url( add_query_arg( array( 'page' => 'el-trustt-general' ), 'admin.php' ) ) ); ?>">
                    <?php esc_html_e( "API", 'trustt' ); ?>
            </a>
            <a class="nav-tab <?php echo $selected == 'el-trustt-ecommerce' ? 'nav-tab-active' : ''; ?>"
                href="<?php echo esc_url( admin_url( add_query_arg( array( 'page' => 'el-trustt-ecommerce' ), 'admin.php' ) ) ); ?>">
                    <?php esc_html_e( "Configuration", 'trustt' ); ?>
            </a>
            <a class="nav-tab <?php echo $selected == 'el-trustt-orders' ? 'nav-tab-active' : ''; ?>"
                href="<?php echo esc_url( admin_url( add_query_arg( array( 'page' => 'el-trustt-orders' ), 'admin.php' ) ) ); ?>">
                    <?php esc_html_e( "Commandes", 'trustt' ); ?>
            </a>
        </h2>
    <?php
    }

    /**
     * Render welcom Screen
     *
     * @access public
     * @since  1.0
     * @return void
     */
    public function el_welcome_screen() {

        // Stupid hack for Wordpress alerts and warnings.
        //echo '<div class="wrap" style="height:0;overflow:hidden;"><h2></h2></div>';
        require_once plugin_dir_path( __FILE__ ). 'partials/tabs/welcome-trustt.php';

    }

    /**
     * Render general Screen
     *
     * @access public
     * @since  1.0
     * @return void
     */
    public function el_general_screen() {

        // Stupid hack for Wordpress alerts and warnings.
        //echo '<div class="wrap" style="height:0;overflow:hidden;"><h2></h2></div>';
        require_once plugin_dir_path( __FILE__ ). 'partials/tabs/general-trustt.php';

    }

    /**
     * Render ecommerce Screen
     *
     * @access public
     * @since  1.0
     * @return void
     */
    public function el_ecommerce_screen() {
        // Stupid hack for Wordpress alerts and warnings.
        //echo '<div class="wrap" style="height:0;overflow:hidden;"><h2></h2></div>';
        require_once plugin_dir_path( __FILE__ ). 'partials/tabs/ecommerce-trustt.php';

    }

    /**
     * Render ecommerce Screen
     *
     * @access public
     * @since  1.1
     * @return void
     */
    public function el_orders_screen() {
        // Stupid hack for Wordpress alerts and warnings.
        //echo '<div class="wrap" style="height:0;overflow:hidden;"><h2></h2></div>';
        require_once plugin_dir_path( __FILE__ ). 'partials/tabs/orders-trustt.php';

    }

    /**
     *  Add Options fields to Config Tab page
     *
     * @since    1.0.0
     */
    public function el_settings_init(  ) {

        add_settings_section(
            'el_setting_section_general_name',
            esc_html__( '', 'trustt'),
            array( $this,  'el_setting_section_callback' ),
            'el-settings-general-group-trustt'
        );

        add_settings_field(
            'el_setting_trustt_api_key',
            esc_html__( 'API Key', 'trustt'),
            array( $this,  'el_setting_trustt_api_key_callback' ),
            'el-settings-general-group-trustt',
            'el_setting_section_general_name'
        );

        add_settings_section(
            'el_setting_section_trustt_ssl',
            esc_html__( '', 'trustt'),
            array( $this,  'el_setting_section_callback' ),
            'el-settings-general-group-trustt'
        );

        add_settings_field(
            'el_setting_trustt_sslverify',
            esc_html__( 'Activer SSL', 'trustt') ,
            array( $this,  'el_setting_section_trustt_ssl_callback' ),
            'el-settings-general-group-trustt',
            'el_setting_section_trustt_ssl'
        );

        register_setting(
            'el-settings-general-group-trustt',
            'el-settings-trustt',
            array( $this,'el_config_tab_validate' )
        );

        add_settings_section(
            'el_setting_section_trustt_preview',
            esc_html__( '', 'trustt'),
            array( $this,  'el_setting_section_callback' ),
            'el-settings-ecommerce-group-trustt'
        );

        add_settings_field(
            'el_setting_trustt_preview_display',
            esc_html__( 'Afficher Avis (Rich Snippets)', 'trustt') ,
            array( $this,  'el_setting_trustt_preview_display_callback' ),
            'el-settings-ecommerce-group-trustt',
            'el_setting_section_trustt_preview'
        );

        add_settings_field(
            'el_setting_trustt_preview_note',
            esc_html__( 'Note Moyenne', 'trustt'),
            array( $this,  'el_setting_trustt_preview_note_callback' ),
            'el-settings-ecommerce-group-trustt',
            'el_setting_section_trustt_preview'
        );

        add_settings_field(
            'el_setting_trustt_preview_avis',
            esc_html__( 'Nombre d\'avis', 'trustt'),
            array( $this,  'el_setting_trustt_preview_avis_callback' ),
            'el-settings-ecommerce-group-trustt',
            'el_setting_section_trustt_preview'
        );

        add_settings_field(
            'el_setting_trustt_preview_empty',
            esc_html__( 'Produit sans avis', 'trustt'),
            array( $this,  'el_setting_trustt_preview_empty_callback' ),
            'el-settings-ecommerce-group-trustt',
            'el_setting_section_trustt_preview'
        );

        register_setting(
            'el-settings-ecommerce-group-trustt',
            'el-settings-trustt',
            array( $this,'el_config_tab_validate' )
        );

        add_settings_section(
            'el_setting_section_trustt_products_synthese',
            esc_html__( '', 'trustt'),
            array( $this,  'el_setting_section_callback' ),
            'el-settings-ecommerce-group-trustt'
        );

        add_settings_field(
            'el_setting_trustt_products_display',
            esc_html__( 'Activer les avis sous le titre du produit', 'trustt') ,
            array( $this,  'el_setting_trustt_products_display_callback' ),
            'el-settings-ecommerce-group-trustt',
            'el_setting_section_trustt_products_synthese'
        );

        add_settings_field(
            'el_setting_trustt_products_display_hook',
            esc_html__( 'Hook d\'affichage', 'trustt') ,
            array( $this,  'el_setting_trustt_products_display_hook_callback' ),
            'el-settings-ecommerce-group-trustt',
            'el_setting_section_trustt_products_synthese'
        );

        add_settings_field(
            'el_setting_trustt_products_display_customer_hook',
            esc_html__( 'Votre Hook d\'affichage', 'trustt') ,
            array( $this,  'el_setting_trustt_products_display_customer_hook_callback' ),
            'el-settings-ecommerce-group-trustt',
            'el_setting_section_trustt_products_synthese',
            array( 'class' => 'el_setting_trustt_products_display_customer_hook el-hidden' )
        );

        add_settings_field(
            'el_setting_trustt_products_synthese_note',
            esc_html__( 'Étoiles', 'trustt') ,
            array( $this,  'el_setting_trustt_products_synthese_note_callback' ),
            'el-settings-ecommerce-group-trustt',
            'el_setting_section_trustt_products_synthese'
        );

        add_settings_field(
            'el_setting_trustt_products_synthese_avis',
            esc_html__( 'Nombre d\'avis', 'trustt') ,
            array( $this,  'el_setting_trustt_products_synthese_avis_callback' ),
            'el-settings-ecommerce-group-trustt',
            'el_setting_section_trustt_products_synthese'
        );

        add_settings_field(
            'el_setting_trustt_products_synthese_empty',
            esc_html__( 'Produit sans avis', 'trustt'),
            array( $this,  'el_setting_trustt_products_synthese_empty_callback' ),
            'el-settings-ecommerce-group-trustt',
            'el_setting_section_trustt_products_synthese'
        );

        add_settings_field(
            'el_setting_trustt_products_synthese_ldjson',
            esc_html__( 'Surcharger les Rich Snippet de WooCommerce', 'trustt'),
            array( $this,  'el_setting_trustt_products_synthese_ldjson_callback' ),
            'el-settings-ecommerce-group-trustt',
            'el_setting_section_trustt_products_synthese'
        );

        register_setting(
            'el-settings-ecommerce-group-trustt',
            'el-settings-trustt',
            array( $this,'el_config_tab_validate' )
        );

        add_settings_section(
            'el_setting_section_trustt_iframe',
            esc_html__( '', 'trustt'),
            array( $this,  'el_setting_section_callback' ),
            'el-settings-ecommerce-group-trustt'
        );

        add_settings_field(
            'el_setting_trustt_iframe_display',
            esc_html__( 'Afficher widget', 'trustt') ,
            array( $this,  'el_setting_trustt_iframe_display_callback' ),
            'el-settings-ecommerce-group-trustt',
            'el_setting_section_trustt_iframe'
        );

        add_settings_field(
            'el_setting_trustt_iframe_display_hook',
            esc_html__( 'Hook d\'affichage', 'trustt') ,
            array( $this,  'el_setting_trustt_iframe_display_hook_callback' ),
            'el-settings-ecommerce-group-trustt',
            'el_setting_section_trustt_iframe'
        );

        add_settings_field(
            'el_setting_trustt_iframe_display_customer_hook',
            esc_html__( 'Votre Hook d\'affichage', 'trustt') ,
            array( $this,  'el_setting_trustt_iframe_display_customer_hook_callback' ),
            'el-settings-ecommerce-group-trustt',
            'el_setting_section_trustt_iframe',
            array( 'class' => 'el_setting_trustt_iframe_display_customer_hook el-hidden' )
        );

        add_settings_field(
            'el_setting_trustt_iframe_avis_ligne',
            esc_html__( 'Nombre d\'avis par ligne', 'trustt') ,
            array( $this,  'el_setting_trustt_iframe_avis_ligne_callback' ),
            'el-settings-ecommerce-group-trustt',
            'el_setting_section_trustt_iframe'
        );

        add_settings_field(
            'el_setting_trustt_iframe_avis_number',
            esc_html__( 'Nombre d\'avis', 'trustt') ,
            array( $this,  'el_setting_trustt_iframe_avis_number_callback' ),
            'el-settings-ecommerce-group-trustt',
            'el_setting_section_trustt_iframe'
        );

        add_settings_field(
            'el_setting_trustt_iframe_avis_order',
            esc_html__( 'Ordre par défaut', 'trustt') ,
            array( $this,  'el_setting_trustt_iframe_avis_order_callback' ),
            'el-settings-ecommerce-group-trustt',
            'el_setting_section_trustt_iframe'
        );

        register_setting(
            'el-settings-orders-group-trustt',
            'el-settings-trustt',
            array( $this,'el_config_tab_validate' )
        );

        add_settings_section(
            'el_setting_section_trustt_orders',
            esc_html__( '', 'trustt'),
            array( $this,  'el_setting_section_callback' ),
            'el-settings-orders-group-trustt'
        );

        add_settings_section(
            'el_setting_section_trustt_orders_',
            esc_html__( '', 'trustt'),
            array( $this,  'el_setting_section_callback_' ),
            'el-settings-orders-group-trustt'
        );

        add_settings_field(
            'el_setting_trustt_iframe_avis_order',
            esc_html__( 'Etat de commande', 'trustt') ,
            array( $this,  'el_setting_trustt_status_order_callback' ),
            'el-settings-orders-group-trustt',
            'el_setting_section_trustt_orders_'
        );

    }

    /**
     *  Renders el_setting_trustt_api_key setting field.
     *
     * @since    1.0.0
     */
    public function el_setting_trustt_api_key_callback() {

        // Get saved options
        $options = $this->el_get_tab_config_options_trustt();

        echo '<div class="uk-inline uk-width-1-1"><span class="uk-form-icon" uk-icon="icon: database"></span><input class="uk-input uk-width-1-1" type="text" id="el_setting_trustt_api_key" name="el-settings-trustt[el_setting_trustt_api_key]" value="'.esc_attr( $options['el_setting_trustt_api_key'] ).'"></div>';
        echo '<p class="description el-text-small">' . __( 'Clé API pour avoir accès aux ressources Trustt', 'trustt') .'</p>';

    }

    /**
     *  Renders el_setting_trustt_products_display_hook setting field.
     *
     * @since    1.0.0
     */
    public function el_setting_trustt_products_display_hook_callback() {
        // Get saved options
        $options           = $this->el_get_tab_config_options_trustt();
        $display           = $options['el_setting_trustt_products_display_hook'] == 'el_trustt_woocommerce_single_product_reviews' ? 'el-display-block' : 'el-hidden';
        $display_shortcode = $options['el_setting_trustt_products_display_hook'] == 'el_trustt_reviews_shortcode' ? 'el-display-block' : 'el-hidden';

        ?>
        <div class="uk-margin" uk-grid>
            <div class="uk-width-1-1">
                <select class="uk-width-1-1" id="el_setting_trustt_products_display_hook" name="el-settings-trustt[el_setting_trustt_products_display_hook]">
                    <?php foreach ( $this->el_setting_trustt_products_display_hook_data() as $button ) { ?>
                        <option value="<?php echo esc_attr( $button['value'] ); ?>" <?php selected( $button['value'], $options['el_setting_trustt_products_display_hook'] ); ?>>
                            <?php echo $button['label']; ?>
                        </option>
                    <?php } ?>
                </select>
                <p class="description el-text-small"><?php esc_html_e( 'Hooks disponible pour l\'affichage', 'trustt' ); ?></p>
                <p class="description el-text-small"><a href="https://www.businessbloomer.com/woocommerce-visual-hook-guide-single-product-page/" target="_blank"><?php esc_html_e( 'Guide visuel des hooks Woocommerce disponibles', 'trustt' ); ?></a></p>
                <div id="el_trustt_woocommerce_single_product_reviews" class="el-hidden <?php echo $display; ?> uk-alert uk-alert-danger">
                    <span uk-icon="icon: warning"></span>&nbsp;<span class="uk-text-uppercase uk-text-middle"><?php esc_html_e( 'Attention', 'trustt' ); ?></span>
                    <p class="description uk-text-danger"><?php esc_html_e( 'Insérer ce code dans votre template :', 'trustt' ); ?></p>
                    <pre><code>&lt;?php do_action( "el_trustt_woocommerce_single_product_reviews" ); ?&gt;</code></pre>
                </div>
                <div id="el_trustt_reviews_shortcode" class="el-hidden <?php echo $display_shortcode; ?> uk-alert uk-alert-danger">
                    <span uk-icon="icon: warning"></span>&nbsp;<span class="uk-text-uppercase uk-text-middle"><?php esc_html_e( 'Attention', 'trustt' ); ?></span>
                    <p class="description uk-text-danger"><?php esc_html_e( 'Insérer ce shortcode dans votre template (uniquement page produit) :', 'trustt' ); ?></p>
                    <pre><code>[el_trustt_reviews title="" tag=""]</code></pre>
                </div>
            </div><!-- .uk-width -->
        </div><!-- .uk-grid -->
        <?php

    }

     /**
     *  Renders el_setting_trustt_iframe_display_hook setting field.
     *
     * @since    1.0.0
     */
    public function el_setting_trustt_iframe_display_hook_callback() {
        // Get saved options
        $options           = $this->el_get_tab_config_options_trustt();
        $display           = $options['el_setting_trustt_iframe_display_hook'] == 'el_trustt_woocommerce_single_product_iframe' ? 'el-display-block' : 'el-hidden';
        $display_shortcode = $options['el_setting_trustt_iframe_display_hook'] == 'el_trustt_iframe_shortcode' ? 'el-display-block' : 'el-hidden';

        ?>
        <div class="uk-margin" uk-grid>
            <div class="uk-width-1-1">
                <select class="uk-width-1-1" id="el_setting_trustt_iframe_display_hook" name="el-settings-trustt[el_setting_trustt_iframe_display_hook]">
                    <?php foreach ( $this->el_setting_trustt_iframe_display_hook_data() as $button ) { ?>
                        <option value="<?php echo esc_attr( $button['value'] ); ?>" <?php selected( $button['value'], $options['el_setting_trustt_iframe_display_hook'] ); ?>>
                            <?php echo $button['label']; ?>
                        </option>
                    <?php } ?>
                </select>
                <p class="description el-text-small"><?php esc_html_e( 'Hooks disponible pour l\'affichage', 'trustt' ); ?></p>
                <p class="description el-text-small"><a href="https://www.businessbloomer.com/woocommerce-visual-hook-guide-single-product-page/" target="_blank"><?php esc_html_e( 'Guide visuel des hooks Woocommerce disponibles', 'trustt' ); ?></a></p>
                <div id="el_trustt_woocommerce_single_product_iframe" class="el-hidden <?php echo $display; ?> uk-alert uk-alert-danger">
                    <span uk-icon="icon: warning"></span>&nbsp;<span class="uk-text-uppercase uk-text-middle"><?php esc_html_e( 'Attention', 'trustt' ); ?></span>
                    <p class="description uk-text-danger"><?php esc_html_e( 'Insérer ce code dans votre template :', 'trustt' ); ?></p>
                    <pre><code>&lt;?php do_action( "el_trustt_woocommerce_single_product_iframe" ); ?&gt;</code></pre>
                </div>
                <div id="el_trustt_iframe_shortcode" class="el-hidden <?php echo $display_shortcode; ?> uk-alert uk-alert-danger">
                    <span uk-icon="icon: warning"></span>&nbsp;<span class="uk-text-uppercase uk-text-middle"><?php esc_html_e( 'Attention', 'trustt' ); ?></span>
                    <p class="description uk-text-danger"><?php esc_html_e( 'Insérer ce shortcode dans votre template (uniquement page produit) :', 'trustt' ); ?></p>
                    <pre><code>[el_trustt_iframe title="" tag=""]</code></pre>
                </div>
            </div><!-- .uk-width -->
        </div><!-- .uk-grid -->
        <?php

    }

    /**
     *  Renders el_setting_trustt_products_display_customer_hook setting field.
     *
     * @since    1.0.0
     */
    public function el_setting_trustt_products_display_customer_hook_callback() {

        // Get saved options
        $options = $this->el_get_tab_config_options_trustt();
        $display   = $options['el_setting_trustt_products_display_hook'] == 'customer_custom_hook' ? 'display: table-row;' : 'display: none;';

        echo '<div class="uk-inline uk-width-1-1"><span class="uk-form-icon" uk-icon="icon: cog"></span><input class="uk-input uk-width-1-1" type="text" id="el_setting_trustt_products_display_customer_hook" name="el-settings-trustt[el_setting_trustt_products_display_customer_hook]" value="' . esc_attr( $options['el_setting_trustt_products_display_customer_hook'] ) . '"></div>';
        echo '<p class="description el-text-small">' . esc_html__( 'Indiquez le nom de votre hook', 'trustt') .'</p>';
        echo '<style>.el_setting_trustt_products_display_customer_hook { ' . $display . ' }</style>';
    }

    /**
     *  Renders el_setting_trustt_iframe_display_customer_hook setting field.
     *
     * @since    1.0.0
     */
    public function el_setting_trustt_iframe_display_customer_hook_callback() {

        // Get saved options
        $options = $this->el_get_tab_config_options_trustt();
        $display   = $options['el_setting_trustt_iframe_display_hook'] == 'customer_custom_hook' ? 'display: table-row;' : 'display: none;';

        echo '<div class="uk-inline uk-width-1-1"><span class="uk-form-icon" uk-icon="icon: cog"></span><input class="uk-input uk-width-1-1" type="text" id="el_setting_trustt_iframe_display_customer_hook" name="el-settings-trustt[el_setting_trustt_iframe_display_customer_hook]" value="' . esc_attr( $options['el_setting_trustt_iframe_display_customer_hook'] ) . '"></div>';
        echo '<p class="description el-text-small">' . esc_html__( 'Indiquez le nom de votre hook', 'trustt') .'</p>';
        echo '<style>.el_setting_trustt_iframe_display_customer_hook { ' . $display . ' }</style>';
    }

    /**
     *  Renders el_setting_trustt_iframe_avis_number setting field.
     *
     * @since    1.0.0
     */
    public function el_setting_trustt_iframe_avis_number_callback() {
        // Get saved options
        $options        = $this->el_get_tab_config_options_trustt(); ?>
        <div class="uk-margin" uk-grid>
            <div class="uk-width-1-1">
                <select class="uk-width-1-1" id="el_setting_trustt_iframe_avis_number" name="el-settings-trustt[el_setting_trustt_iframe_avis_number]">
                    <?php foreach ( $this->el_setting_trustt_iframe_avis_number_data() as $button ) { ?>
                        <option value="<?php echo esc_attr( $button['value'] ); ?>" <?php selected( $button['value'], $options['el_setting_trustt_iframe_avis_number'] ); ?>>
                            <?php echo $button['label']; ?>
                        </option>
                    <?php } ?>
                </select>
                <p class="description el-text-small"><?php _e( 'Nombre d\'avis par page', 'trustt') ?></p>
            </div><!-- .uk-width -->
        </div><!-- .uk-grid -->
        <?php

    }

    /**
     *  Renders el_setting_trustt_iframe_avis_order setting field.
     *
     * @since    1.0.0
     */
    public function el_setting_trustt_iframe_avis_order_callback() {
        // Get saved options
        $options        = $this->el_get_tab_config_options_trustt(); ?>
        <div class="uk-margin" uk-grid>
            <div class="uk-width-1-1">
                <select class="uk-width-1-1" id="el_setting_trustt_iframe_avis_order" name="el-settings-trustt[el_setting_trustt_iframe_avis_order]">
                    <?php foreach ( $this->el_setting_trustt_iframe_avis_order_data() as $button ) { ?>
                        <option value="<?php echo esc_attr( $button['value'] ); ?>" <?php selected( $button['value'], $options['el_setting_trustt_iframe_avis_order'] ); ?>>
                            <?php echo $button['label']; ?>
                        </option>
                    <?php } ?>
                </select>
                <p class="description el-text-small"><?php _e( 'Ordre par défault des avis', 'trustt') ?></p>
            </div><!-- .uk-width -->
        </div><!-- .uk-grid -->
        <?php

    }

    /**
     *  Renders el_setting_trustt_status_order setting field.
     *
     * @since    1.1.0
     */
    public function el_setting_trustt_status_order_callback() {
        // Get saved options
        $options        = $this->el_get_tab_config_options_trustt();?>
        <div class="uk-margin" uk-grid>
            <div class="uk-width-1-1">
                <select class="uk-width-1-1" id="el_setting_trustt_status_order" name="el-settings-trustt[el_setting_trustt_status_order]">
                    <?php foreach ( $this->el_setting_trustt_status_order_data() as $slug => $label ) { ?>
                        <option value="<?php echo esc_attr( $slug ); ?>" <?php selected( $slug, $options['el_setting_trustt_status_order'] ); ?>>
                            <?php echo $label; ?>
                        </option>
                    <?php } ?>
                </select>
                <p class="description el-text-small"><?php _e( 'Choisir l\'état de commande qui déclenchera l\'envoi des mails de demande d\'avis', 'trustt') ?></p>
            </div><!-- .uk-width -->
        </div><!-- .uk-grid -->
        <?php

    }

    /**
     *  Renders el_setting_trustt_iframe_avis_ligne setting field.
     *
     * @since    1.0.0
     */
    public function el_setting_trustt_iframe_avis_ligne_callback() {
        // Get saved options
        $options        = $this->el_get_tab_config_options_trustt(); ?>
        <div class="uk-margin" uk-grid>
            <div class="uk-width-1-1">
                <select class="uk-width-1-1" id="el_setting_trustt_iframe_avis_ligne" name="el-settings-trustt[el_setting_trustt_iframe_avis_ligne]">
                    <?php foreach ( $this->el_setting_trustt_iframe_avis_ligne_data() as $button ) { ?>
                        <option value="<?php echo esc_attr( $button['value'] ); ?>" <?php selected( $button['value'], $options['el_setting_trustt_iframe_avis_ligne'] ); ?>>
                            <?php echo $button['label']; ?>
                        </option>
                    <?php } ?>
                </select>
                <p class="description el-text-small"><?php _e( 'Nombre d\'avis par ligne', 'trustt') ?></p>
            </div><!-- .uk-width -->
        </div><!-- .uk-grid -->
        <?php

    }

    /**
     *  Array for Select field el_setting_trustt_status_order
     *
     * @since    1.1.0
     */
    public function el_setting_trustt_status_order_data() {

        $el_setting_trustt_status_order = get_posts( array(
            'post_type'   => 'wc_order_status',
            'post_status' => 'publish',
            'numberposts' => -1
            )
        );

        $statuts = array();
        foreach ( $el_setting_trustt_status_order as $statut ) {
          $statuts[ $statut->post_name ] = $statut->post_title;
        }

        $result = array_merge( wc_get_order_statuses(), $statuts );

        return $result;
    }

    /**
     *  Array for Select field el_setting_trustt_iframe_avis_order
     *
     * @since    1.0.0
     */
    public function el_setting_trustt_iframe_avis_order_data() {

        $el_setting_trustt_iframe_avis_order = array(
            'date_desc' => array(
                'value' => 'date_desc',
                'label' => esc_html__( 'Les plus récents', 'trustt' ),
            ),
            'influencer_desc' => array(
                'value' => 'influencer_desc',
                'label' => esc_html__( 'Expert·e beauté', 'trustt' ),
            ),
            'useful_desc' => array(
                'value' => 'useful_desc',
                'label' => esc_html__( 'Les plus utiles', 'trustt' ),
            ),
            'rating_desc' => array(
                'value' => 'rating_desc',
                'label' => esc_html__( 'Note la plus élevée', 'trustt' ),
            ),
        );
        return apply_filters( 'el_setting_trustt_iframe_avis_order_data', $el_setting_trustt_iframe_avis_order );
    }

    /**
     *  Array for Select field el_setting_trustt_iframe_avis_ligne
     *
     * @since    1.0.0
     */
    public function el_setting_trustt_iframe_avis_ligne_data() {

        $el_setting_trustt_iframe_avis_ligne = array(

            1 => array(
                'value' => 1,
                'label' => esc_html__( '1', 'trustt' ),
            ),

            2 => array(
                'value' => 2,
                'label' => esc_html__( '2', 'trustt' ),
            ),

        );
        return apply_filters( 'el_setting_trustt_iframe_avis_ligne_data', $el_setting_trustt_iframe_avis_ligne );
    }

    /**
     *  Array for Select field el_setting_trustt_iframe_avis_number
     *
     * @since    1.0.0
     */
    public function el_setting_trustt_iframe_avis_number_data() {

        $el_setting_trustt_iframe_avis_number = array(
            4 => array(
                'value' => 4,
                'label' => esc_html__( '4', 'trustt' ),
            ),
            6 => array(
                'value' => 6,
                'label' => esc_html__( '6', 'trustt' ),
            ),
            8 => array(
                'value' => 8,
                'label' => esc_html__( '8', 'trustt' ),
            ),
            10 => array(
                'value' => 10,
                'label' => esc_html__( '10', 'trustt' ),
            ),
            12 => array(
                'value' => 12,
                'label' => esc_html__( '12', 'trustt' ),
            ),
            24 => array(
                'value' => 24,
                'label' => esc_html__( '24', 'trustt' ),
            ),
        );
        return apply_filters( 'el_setting_trustt_iframe_avis_number_data', $el_setting_trustt_iframe_avis_number );
    }

    /**
     *  Array for Select field el_setting_trustt_products_display_hook
     *
     * @since    1.0.0
     */
    public function el_setting_trustt_products_display_hook_data() {

        $el_setting_trustt_products_display_hook = array(
            'woocommerce_before_single_product' => array(
                'value' => 'woocommerce_before_single_product',
                'label' => esc_html__( 'woocommerce_before_single_product', 'trustt' ),
            ),
            'woocommerce_before_single_product_summary' => array(
                'value' => 'woocommerce_before_single_product_summary',
                'label' => esc_html__( 'woocommerce_before_single_product_summary', 'trustt' ),
            ),
            'woocommerce_single_product_summary' => array(
                'value' => 'woocommerce_single_product_summary',
                'label' => esc_html__( 'woocommerce_single_product_summary', 'trustt' ),
            ),
            'woocommerce_before_add_to_cart_form' => array(
                'value' => 'woocommerce_before_add_to_cart_form',
                'label' => esc_html__( 'woocommerce_before_add_to_cart_form', 'trustt' ),
            ),
            'woocommerce_before_variations_form' => array(
                'value' => 'woocommerce_before_variations_form',
                'label' => esc_html__( 'woocommerce_before_variations_form', 'trustt' ),
            ),
            'woocommerce_before_add_to_cart_button' => array(
                'value' => 'woocommerce_before_add_to_cart_button',
                'label' => esc_html__( 'woocommerce_before_add_to_cart_button', 'trustt' ),
            ),
            'woocommerce_before_single_variation' => array(
                'value' => 'woocommerce_before_single_variation',
                'label' => esc_html__( 'woocommerce_before_single_variation', 'trustt' ),
            ),
            'woocommerce_single_variation' => array(
                'value' => 'woocommerce_single_variation',
                'label' => esc_html__( 'woocommerce_single_variation', 'trustt' ),
            ),
            'woocommerce_before_add_to_cart_quantity' => array(
                'value' => 'woocommerce_before_add_to_cart_quantity',
                'label' => esc_html__( 'woocommerce_before_add_to_cart_quantity', 'trustt' ),
            ),
            'woocommerce_after_add_to_cart_quantity' => array(
                'value' => 'woocommerce_after_add_to_cart_quantity',
                'label' => esc_html__( 'woocommerce_after_add_to_cart_quantity', 'trustt' ),
            ),
            'woocommerce_after_single_variation' => array(
                'value' => 'woocommerce_after_single_variation',
                'label' => esc_html__( 'woocommerce_after_single_variation', 'trustt' ),
            ),
            'woocommerce_after_add_to_cart_button' => array(
                'value' => 'woocommerce_after_add_to_cart_button',
                'label' => esc_html__( 'woocommerce_after_add_to_cart_button', 'trustt' ),
            ),
            'woocommerce_after_add_to_cart_button' => array(
                'value' => 'woocommerce_after_variations_form',
                'label' => esc_html__( 'woocommerce_after_variations_form', 'trustt' ),
            ),
            'woocommerce_after_add_to_cart_form' => array(
                'value' => 'woocommerce_after_add_to_cart_form',
                'label' => esc_html__( 'woocommerce_after_add_to_cart_form', 'trustt' ),
            ),
            'woocommerce_product_meta_start' => array(
                'value' => 'woocommerce_product_meta_start',
                'label' => esc_html__( 'woocommerce_product_meta_start', 'trustt' ),
            ),
            'woocommerce_product_meta_end' => array(
                'value' => 'woocommerce_product_meta_end',
                'label' => esc_html__( 'woocommerce_product_meta_end', 'trustt' ),
            ),
            'woocommerce_share' => array(
                'value' => 'woocommerce_share',
                'label' => esc_html__( 'woocommerce_share', 'trustt' ),
            ),
            'woocommerce_after_single_product_summary' => array(
                'value' => 'woocommerce_after_single_product_summary',
                'label' => esc_html__( 'woocommerce_after_single_product_summary', 'trustt' ),
            ),
            'woocommerce_after_single_product' => array(
                'value' => 'woocommerce_after_single_product',
                'label' => esc_html__( 'woocommerce_after_single_product', 'trustt' ),
            ),
            'el_trustt_woocommerce_single_product_reviews' => array(
                'value' => 'el_trustt_woocommerce_single_product_reviews',
                'label' => esc_html__( 'Trustt Hook personnalisé', 'trustt' ),
            ),
            'customer_custom_hook' => array(
                'value' => 'customer_custom_hook',
                'label' => esc_html__( 'Votre Hook personnalisé', 'trustt' ),
            ),
            'el_trustt_reviews_shortcode' => array(
                'value' => 'el_trustt_reviews_shortcode',
                'label' => esc_html__( 'Shortcode', 'trustt' ),
            ),
        );
        return apply_filters( 'el_setting_trustt_products_display_hook_data', $el_setting_trustt_products_display_hook );
    }

    /**
     *  Array for Select field el_setting_trustt_iframe_display_hook
     *
     * @since    1.0.0
     */
    public function el_setting_trustt_iframe_display_hook_data() {

        $el_setting_trustt_iframe_display_hook = array(
            'woocommerce_before_single_product' => array(
                'value' => 'woocommerce_before_single_product',
                'label' => esc_html__( 'woocommerce_before_single_product', 'trustt' ),
            ),
            'woocommerce_before_single_product_summary' => array(
                'value' => 'woocommerce_before_single_product_summary',
                'label' => esc_html__( 'woocommerce_before_single_product_summary', 'trustt' ),
            ),
            'woocommerce_single_product_summary' => array(
                'value' => 'woocommerce_single_product_summary',
                'label' => esc_html__( 'woocommerce_single_product_summary', 'trustt' ),
            ),
            'woocommerce_before_add_to_cart_form' => array(
                'value' => 'woocommerce_before_add_to_cart_form',
                'label' => esc_html__( 'woocommerce_before_add_to_cart_form', 'trustt' ),
            ),
            'woocommerce_before_variations_form' => array(
                'value' => 'woocommerce_before_variations_form',
                'label' => esc_html__( 'woocommerce_before_variations_form', 'trustt' ),
            ),
            'woocommerce_before_add_to_cart_button' => array(
                'value' => 'woocommerce_before_add_to_cart_button',
                'label' => esc_html__( 'woocommerce_before_add_to_cart_button', 'trustt' ),
            ),
            'woocommerce_before_single_variation' => array(
                'value' => 'woocommerce_before_single_variation',
                'label' => esc_html__( 'woocommerce_before_single_variation', 'trustt' ),
            ),
            'woocommerce_single_variation' => array(
                'value' => 'woocommerce_single_variation',
                'label' => esc_html__( 'woocommerce_single_variation', 'trustt' ),
            ),
            'woocommerce_before_add_to_cart_quantity' => array(
                'value' => 'woocommerce_before_add_to_cart_quantity',
                'label' => esc_html__( 'woocommerce_before_add_to_cart_quantity', 'trustt' ),
            ),
            'woocommerce_after_add_to_cart_quantity' => array(
                'value' => 'woocommerce_after_add_to_cart_quantity',
                'label' => esc_html__( 'woocommerce_after_add_to_cart_quantity', 'trustt' ),
            ),
            'woocommerce_after_single_variation' => array(
                'value' => 'woocommerce_after_single_variation',
                'label' => esc_html__( 'woocommerce_after_single_variation', 'trustt' ),
            ),
            'woocommerce_after_add_to_cart_button' => array(
                'value' => 'woocommerce_after_add_to_cart_button',
                'label' => esc_html__( 'woocommerce_after_add_to_cart_button', 'trustt' ),
            ),
            'woocommerce_after_add_to_cart_button' => array(
                'value' => 'woocommerce_after_variations_form',
                'label' => esc_html__( 'woocommerce_after_variations_form', 'trustt' ),
            ),
            'woocommerce_after_add_to_cart_form' => array(
                'value' => 'woocommerce_after_add_to_cart_form',
                'label' => esc_html__( 'woocommerce_after_add_to_cart_form', 'trustt' ),
            ),
            'woocommerce_product_meta_start' => array(
                'value' => 'woocommerce_product_meta_start',
                'label' => esc_html__( 'woocommerce_product_meta_start', 'trustt' ),
            ),
            'woocommerce_product_meta_end' => array(
                'value' => 'woocommerce_product_meta_end',
                'label' => esc_html__( 'woocommerce_product_meta_end', 'trustt' ),
            ),
            'woocommerce_share' => array(
                'value' => 'woocommerce_share',
                'label' => esc_html__( 'woocommerce_share', 'trustt' ),
            ),
            'woocommerce_after_single_product_summary' => array(
                'value' => 'woocommerce_after_single_product_summary',
                'label' => esc_html__( 'woocommerce_after_single_product_summary', 'trustt' ),
            ),
            'woocommerce_after_single_product' => array(
                'value' => 'woocommerce_after_single_product',
                'label' => esc_html__( 'woocommerce_after_single_product', 'trustt' ),
            ),
            'el_trustt_woocommerce_single_product_iframe' => array(
                'value' => 'el_trustt_woocommerce_single_product_iframe',
                'label' => esc_html__( 'Trustt Hook personnalisé', 'trustt' ),
            ),
            'customer_custom_hook' => array(
                'value' => 'customer_custom_hook',
                'label' => esc_html__( 'Votre Hook personnalisé', 'trustt' ),
            ),
            'el_trustt_iframe_shortcode' => array(
                'value' => 'el_trustt_iframe_shortcode',
                'label' => esc_html__( 'Shortcode', 'trustt' ),
            ),
        );
        return apply_filters( 'el_setting_trustt_iframe_display_hook_data', $el_setting_trustt_iframe_display_hook );
    }

    /**
     *  Render Section field
     *
     * @since    1.0.0
     */
    public function el_setting_section_ecommerce_callback() {

        ?>
        <div>

            <span class="uk-text-uppercase"><?php esc_html_e( 'Général','trustt' ); ?></span>
            <hr class="uk-margin-small-top">

        </div>
        <?php
    }

    /**
     *  Render Alert box
     *
     * @since    1.1.0
     */
    public function el_setting_section_callback_() {
        $text = '
            <div id="" class="uk-alert uk-alert-primary">
                <span uk-icon="icon: question"></span>&nbsp;<span class="uk-text-uppercase uk-text-middle">' . esc_html__( 'Information','trustt' ) . '</span>
                <p class="description uk-text-primary uk-margin">
                ' . esc_html__( 'Un email sera envoyé par Trustt à vos clients pour les inviter à déposer un avis sur les produits achetés. Veuillez sélectionner ci-dessous l\'état de commande qui déclenchera cet email.','trustt' ) . '
                </p>
            </div>';
        echo $text;
    }

    public function el_setting_section_callback($section_passed) {


        if ( $section_passed['id'] == 'el_setting_section_general_name' ){
            $title = __( 'Clé API','trustt' );
        }
        if ( $section_passed['id'] == 'el_setting_section_trustt_ssl' ){
            $title = __( 'SSL','trustt' );
        }
        if ( $section_passed['id'] == 'el_setting_section_trustt_preview' ){
            $title = __( 'Aperçu de produit','trustt' );
        }
        if ( $section_passed['id'] == 'el_setting_section_trustt_products_synthese' ){
            $title = __( 'Fiche produits - synthèse des avis','trustt' );
        }
        if ( $section_passed['id'] == 'el_setting_section_trustt_iframe' ){
            $title = __( 'Fiche produits - liste des avis','trustt' );
        }
        if ( $section_passed['id'] == 'el_setting_section_trustt_orders' ){
            $title = __( 'Avis après achat','trustt' );
        }

        if ( isset( $title ) ) : ?>

            <div id="<?php echo $section_passed['id']; ?>" class="uk-panel uk-panel-box uk-panel-box-primary">
                <span class="uk-text-uppercase uk-h3 uk-text-bold uk-text-primary"><?php echo $title; ?></span>
                <hr class="uk-margin-small-top">
            </div>
            <?php else : ?>
                <div class="uk-margin uk-panel uk-panel-box uk-panel-box-primary">
                    <p><?php esc_html_e('Settings for Trustt ','trustt'); ?></p>
                </div>
            <?php endif; ?>
        <?php
     }

    /**
     *  Add Options fields to Config Tab page
     *
     * @since    1.0.0
     */
    public function el_get_tab_config_options_trustt() {

        $saved    = (array) get_option( 'el-settings-trustt' );
        $defaults = $this->el_default_tab_config_options_trustt();
        $defaults = apply_filters( 'el_default_tab_config_options_trustt_filter', $defaults );
        $options  = wp_parse_args( $saved, $defaults );
        $options  = array_intersect_key( $options, $defaults );

        return $options;
    }

    /**
     *  Renders el_setting_trustt_preview_note setting field.
     *
     * @since    1.0.0
     */
    public function el_setting_trustt_preview_note_callback() {

        // Get saved options.
        $options = $this->el_get_tab_config_options_trustt(); ?>

        <div class="uk-margin" uk-grid>
            <div class="uk-width-1-2@m">
                <div class="uk-form-controls uk-form-controls-text">
                <?php foreach ( $this->el_setting_yes_no_data() as $button ) { ?>
                    <label>
                        <input type="radio" id="el_setting_trustt_preview_note" name="el-settings-trustt[el_setting_trustt_preview_note]" value="<?php echo esc_attr( $button['value'] ); ?>" <?php checked( $options['el_setting_trustt_preview_note'], $button['value'] ); ?> />
                        <?php echo $button['label']; ?>
                    </label>
                <?php } ?>
                </div>
                <p class="description el-text-small"><?php _e( 'Afficher la note moyenne dans les aperçus des produits', 'trustt') ?></p>
            </div><!-- .uk-width -->
        </div><!-- .uk-grid -->
        <?php
    }

    /**
     *  Renders el_setting_trustt_preview_avis setting field.
     *
     * @since    1.0.0
     */
    public function el_setting_trustt_preview_avis_callback() {

        // Get saved options.
        $options = $this->el_get_tab_config_options_trustt(); ?>

        <div class="uk-margin" uk-grid>
            <div class="uk-width-1-2@m">
                <div class="uk-form-controls uk-form-controls-text">
                <?php foreach ( $this->el_setting_yes_no_data() as $button ) { ?>
                    <label>
                        <input type="radio" id="el_setting_trustt_preview_avis" name="el-settings-trustt[el_setting_trustt_preview_avis]" value="<?php echo esc_attr( $button['value'] ); ?>" <?php checked( $options['el_setting_trustt_preview_avis'], $button['value'] ); ?> />
                        <?php echo $button['label']; ?>
                    </label>
                <?php } ?>
                </div>
                <p class="description el-text-small"><?php _e( 'Afficher le nombre d\'avis dans les aperçus des produits', 'trustt') ?></p>
            </div><!-- .uk-width -->
        </div><!-- .uk-grid -->
        <?php
    }

    /**
     *  Renders el_setting_trustt_preview_empty setting field.
     *
     * @since    1.0.0
     */
    public function el_setting_trustt_preview_empty_callback() {

        // Get saved options.
        $options = $this->el_get_tab_config_options_trustt(); ?>

        <div class="uk-margin" uk-grid>
            <div class="uk-width-1-2@m">
                <div class="uk-form-controls uk-form-controls-text">
                    <?php foreach ( $this->el_setting_yes_no_data() as $button ) { ?>
                        <label>
                            <input type="radio" id="el_setting_trustt_preview_empty" name="el-settings-trustt[el_setting_trustt_preview_empty]" value="<?php echo esc_attr( $button['value'] ); ?>" <?php checked( $options['el_setting_trustt_preview_empty'], $button['value'] ); ?> />
                            <?php echo $button['label']; ?>
                        </label>
                    <?php } ?>
                </div>
                <p class="description el-text-small"><?php _e( 'Afficher les étoiles pour les produits sans avis', 'trustt') ?></p>
            </div><!-- .uk-width -->
        </div><!-- .uk-grid -->
        <?php
    }

    /**
     *  Renders el_setting_trustt_products_synthese_note setting field.
     *
     * @since    1.0.0
     */
    public function el_setting_trustt_products_synthese_note_callback() {

        // Get saved options.
        $options = $this->el_get_tab_config_options_trustt(); ?>

        <div class="uk-margin" uk-grid>
            <div class="uk-width-1-2@m">
                <div class="uk-form-controls uk-form-controls-text">
                <?php foreach ( $this->el_setting_yes_no_data() as $button ) { ?>
                    <label>
                        <input type="radio" id="el_setting_trustt_products_synthese_note" name="el-settings-trustt[el_setting_trustt_products_synthese_note]" value="<?php echo esc_attr( $button['value'] ); ?>" <?php checked( $options['el_setting_trustt_products_synthese_note'], $button['value'] ); ?> />
                        <?php echo $button['label']; ?>
                    </label>
                <?php } ?>
                </div>
                <p class="description el-text-small"><?php _e( 'Activer les avis sous le nom du produit', 'trustt') ?></p>
            </div><!-- .uk-width -->
        </div><!-- .uk-grid -->
        <?php
    }

    /**
     *  Renders el_setting_trustt_products_synthese_avis setting field.
     *
     * @since    1.1.2
     */
    public function el_setting_trustt_products_synthese_avis_callback() {

        // Get saved options.
        $options = $this->el_get_tab_config_options_trustt(); ?>

        <div class="uk-margin" uk-grid>
            <div class="uk-width-1-2@m">
                <div class="uk-form-controls uk-form-controls-text">
                <?php foreach ( $this->el_setting_yes_no_data() as $button ) { ?>
                    <label>
                        <input type="radio" id="el_setting_trustt_products_synthese_avis" name="el-settings-trustt[el_setting_trustt_products_synthese_avis]" value="<?php echo esc_attr( $button['value'] ); ?>" <?php checked( $options['el_setting_trustt_products_synthese_avis'], $button['value'] ); ?> />
                        <?php echo $button['label']; ?>
                    </label>
                <?php } ?>
                </div>
                <p class="description el-text-small"><?php _e( 'Afficher le nombre d\'avis sous le nom du produit', 'trustt') ?></p>
            </div><!-- .uk-width -->
        </div><!-- .uk-grid -->
        <?php
    }

    /**
     *  Renders el_setting_trustt_preview_empty setting field.
     *
     * @since    1.1.2
     */
    public function el_setting_trustt_products_synthese_empty_callback() {

        // Get saved options.
        $options = $this->el_get_tab_config_options_trustt(); ?>

        <div class="uk-margin" uk-grid>
            <div class="uk-width-1-2@m">
                <div class="uk-form-controls uk-form-controls-text">
                    <?php foreach ( $this->el_setting_yes_no_data() as $button ) { ?>
                        <label>
                            <input type="radio" id="el_setting_trustt_products_synthese_empty" name="el-settings-trustt[el_setting_trustt_products_synthese_empty]" value="<?php echo esc_attr( $button['value'] ); ?>" <?php checked( $options['el_setting_trustt_products_synthese_empty'], $button['value'] ); ?> />
                            <?php echo $button['label']; ?>
                        </label>
                    <?php } ?>
                </div>
                <p class="description el-text-small"><?php _e( 'Afficher les étoiles pour les produits sans avis, sinon le moudle affiche un lien vers l\'ancre de la rubrique avis', 'trustt') ?></p>
            </div><!-- .uk-width -->
        </div><!-- .uk-grid -->
        <?php
    }

    /**
     *  Renders el_setting_trustt_products_synthese_ldjson setting field.
     *
     * @since    1.2
     */
    public function el_setting_trustt_products_synthese_ldjson_callback() {

        // Get saved options.
        $options = $this->el_get_tab_config_options_trustt(); ?>

        <div class="uk-margin" uk-grid>
            <div class="uk-width-1-2@m">
                <div class="uk-form-controls uk-form-controls-text">
                    <?php foreach ( $this->el_setting_yes_no_data() as $button ) { ?>
                        <label>
                            <input type="radio" id="el_setting_trustt_products_synthese_ldjson" name="el-settings-trustt[el_setting_trustt_products_synthese_ldjson]" value="<?php echo esc_attr( $button['value'] ); ?>" <?php checked( $options['el_setting_trustt_products_synthese_ldjson'], $button['value'] ); ?> />
                            <?php echo $button['label']; ?>
                        </label>
                    <?php } ?>
                </div>
                <p class="description el-text-small"><?php _e( 'Rich Snippet : surcharger le ld+json de WooCommerce avec les avis Trustt', 'trustt') ?></p>
            </div><!-- .uk-width -->
        </div><!-- .uk-grid -->
        <?php
    }

    /**
     *  Renders el_setting_trustt_iframe_display setting field.
     *
     * @since    1.0.0
     */
    public function el_setting_trustt_iframe_display_callback() {

        // Get saved options.
        $options = $this->el_get_tab_config_options_trustt(); ?>

        <div class="uk-margin" uk-grid>
            <div class="uk-width-1-2@m">
                <div class="uk-form-controls uk-form-controls-text">
                <?php foreach ( $this->el_setting_yes_no_data() as $button ) { ?>
                    <label>
                        <input type="radio" id="el_setting_trustt_iframe_display" name="el-settings-trustt[el_setting_trustt_iframe_display]" value="<?php echo esc_attr( $button['value'] ); ?>" <?php checked( $options['el_setting_trustt_iframe_display'], $button['value'] ); ?> />
                        <?php echo $button['label']; ?>
                    </label>
                <?php } ?>
                </div>
                <p class="description el-text-small"><?php _e( 'Afficher le widget Trustt dans la fiche produit.', 'trustt') ?></p>
            </div><!-- .uk-width -->
        </div><!-- .uk-grid -->
        <?php
    }

    /**
     *  Renders el_setting_trustt_products_display setting field.
     *
     * @since    1.0.0
     */
    public function el_setting_trustt_products_display_callback() {

        // Get saved options.
        $options = $this->el_get_tab_config_options_trustt(); ?>

        <div class="uk-margin" uk-grid>
            <div class="uk-width-1-2@m">
                <div class="uk-form-controls uk-form-controls-text">
                <?php foreach ( $this->el_setting_yes_no_data() as $button ) { ?>
                    <label>
                        <input type="radio" id="el_setting_trustt_products_display" name="el-settings-trustt[el_setting_trustt_products_display]" value="<?php echo esc_attr( $button['value'] ); ?>" <?php checked( $options['el_setting_trustt_products_display'], $button['value'] ); ?> />
                        <?php echo $button['label']; ?>
                    </label>
                <?php } ?>
                </div>
                <p class="description el-text-small"><?php _e( 'Afficher les avis sous le titre du produit', 'trustt') ?></p>
            </div><!-- .uk-width -->
        </div><!-- .uk-grid -->
        <?php
    }

    /**
     *  Renders el_setting_trustt_preview_display setting field.
     *
     * @since    1.0.0
     */
    public function el_setting_trustt_preview_display_callback() {

        // Get saved options.
        $options = $this->el_get_tab_config_options_trustt(); ?>

        <div class="uk-margin" uk-grid>
            <div class="uk-width-1-2@m">
                <div class="uk-form-controls uk-form-controls-text">
                <?php foreach ( $this->el_setting_yes_no_data() as $button ) { ?>
                    <label>
                        <input type="radio" id="el_setting_trustt_preview_display" name="el-settings-trustt[el_setting_trustt_preview_display]" value="<?php echo esc_attr( $button['value'] ); ?>" <?php checked( $options['el_setting_trustt_preview_display'], $button['value'] ); ?> />
                        <?php echo $button['label']; ?>
                    </label>
                <?php } ?>
                </div>
                <p class="description el-text-small"><?php _e( 'Afficher les avis (Rich Snippets) Trustt dans les aperçus produit.', 'trustt') ?></p>
            </div><!-- .uk-width -->
        </div><!-- .uk-grid -->
        <div id="el_trustt_reviews_shortcode" class="uk-alert uk-alert-warning">
            <span uk-icon="icon: warning"></span>&nbsp;<span class="uk-text-uppercase uk-text-middle"><?php esc_html_e( 'Information', 'trustt' ); ?></span>
            <p class="description uk-text-warning"><?php esc_html_e( 'Cette option permet d\'afficher les étoiles dans les templates standards de WooCommerce. Pour insérer les étoiles à d\'autres endroits, utiliser ce shortcode dans votre template (en précisant bien l\'ID du produit) :', 'trustt' ); ?></p>
            <pre><code>[el_trustt_reviews_page id=" ... "]</code></pre>
        </div>
        <?php
    }

    /**
     *  Renders el_setting_section_trustt_ssl setting field.
     *
     * @since    1.1.0
     */
    public function el_setting_section_trustt_ssl_callback() {

        // Get saved options.
        $options = $this->el_get_tab_config_options_trustt(); ?>

        <div class="uk-margin" uk-grid>
            <div class="uk-width-1-2@m">
                <div class="uk-form-controls uk-form-controls-text">
                <?php foreach ( $this->el_setting_yes_no_data() as $button ) { ?>
                    <label>
                        <input type="radio" id="el_setting_section_trustt_ssl" name="el-settings-trustt[el_setting_section_trustt_ssl]" value="<?php echo esc_attr( $button['value'] ); ?>" <?php checked( $options['el_setting_section_trustt_ssl'], $button['value'] ); ?> />
                        <?php echo $button['label']; ?>
                    </label>
                <?php } ?>
                </div>
                <p class="description el-text-small"><?php _e( 'Activer la vérification SSL lors de l\'appel aux serveurs Trustt', 'trustt') ?></p>
            </div><!-- .uk-width -->
        </div><!-- .uk-grid -->
        <?php
    }

    /**
     *  Array for Radio Buttons el_setting_yes_no_data
     *
     * @since    1.0.0
     */
    public function el_setting_yes_no_data() {

        $el_setting_yes_no_data = array(
            1 => array(
                'value' => 1,
                'label' => esc_html__( 'Oui', 'trustt' ),
            ),
            0 => array(
                'value' => 0,
                'label' => esc_html__( 'Non', 'trustt' ),
            )
        );
        return apply_filters( 'el_setting_yes_no_data', $el_setting_yes_no_data );
    }

    /**
     *  Check if wp_debug is TRUE
     *
     * @since    1.0.0
     */
    private function ifdebug() {

        if ( WP_DEBUG ) {
                $min ='.';
            } else {
                $min ='.min.';

            }
            return $min;
    }

    /**
     *  Default value el-settings-trustt
     *
     * @return     array
     * @since   1.0.0
     */
    public function el_default_tab_config_options_trustt() {

        $defaults = array(
            'el_setting_trustt_api_key'                        => '',
            'el_setting_trustt_preview_note'                   => 1,
            'el_setting_trustt_preview_avis'                   => 1,
            'el_setting_trustt_preview_empty'                  => 1,
            'el_setting_trustt_products_synthese_note'         => 1,
            'el_setting_trustt_products_synthese_avis'         => 1,
            'el_setting_trustt_products_synthese_empty'        => 1,
            'el_setting_trustt_products_synthese_ldjson'       => 0,
            'el_setting_trustt_iframe_avis_ligne'              => 2,
            'el_setting_trustt_iframe_avis_number'             => 6,
            'el_setting_trustt_iframe_avis_order'              => 'date_desc',
            'el_setting_trustt_iframe_display'                 => 1,
            'el_setting_trustt_products_display'               => 1,
            'el_setting_trustt_preview_display'                => 1,
            'el_setting_section_trustt_ssl'                    => 0,
            'el_setting_trustt_products_display_hook'          => 'woocommerce_single_product_summary',
            'el_setting_trustt_products_display_customer_hook' => '',
            'el_setting_trustt_iframe_display_hook'            => 'woocommerce_single_product_summary',
            'el_setting_trustt_iframe_display_customer_hook'   => '',
            'el_setting_trustt_status_order'                   => 'wc-completed'
        );

        return $defaults;

    }

    /**
     *  Add Options fields to Config Tab page
     *
     * @since    1.0.0
     */
    public function el_get_tab_config_options_sites_trustt() {

        $saved    = (array) get_option( 'el-settings-sites-trustt' );
        $defaults = $this->el_default_tab_config_options_sites_trustt();
        $defaults = apply_filters( 'el_default_tab_config_options_sites_trustt_filter', $defaults );
        $options  = wp_parse_args( $saved, $defaults );
        $options  = array_intersect_key( $options, $defaults );

        return $options;
    }

    /**
     *  Validate fields el-settings-trustt
     *
     * @since    1.0.0
     */
    public function el_config_tab_validate( $input ) {

        $hasError = false;

        if ( isset( $_POST['reset'] ) ) {
            $output = array();
        } else {
            $output = get_option('el-settings-trustt');
        }

		if ( isset( $input['el_setting_trustt_api_key'] ) ) {
			$output['el_setting_trustt_api_key'] = sanitize_text_field( $input['el_setting_trustt_api_key'] );
		}

        if ( isset( $input['el_setting_trustt_preview_note'] ) && array_key_exists( $input['el_setting_trustt_preview_note'], $this->el_setting_yes_no_data() ) )
        $output['el_setting_trustt_preview_note'] = $input['el_setting_trustt_preview_note'];

        if ( isset( $input['el_setting_trustt_preview_avis'] ) && array_key_exists( $input['el_setting_trustt_preview_avis'], $this->el_setting_yes_no_data() ) )
        $output['el_setting_trustt_preview_avis'] = $input['el_setting_trustt_preview_avis'];

        if ( isset( $input['el_setting_trustt_preview_empty'] ) && array_key_exists( $input['el_setting_trustt_preview_empty'], $this->el_setting_yes_no_data() ) )
            $output['el_setting_trustt_preview_empty'] = $input['el_setting_trustt_preview_empty'];

        if ( isset( $input['el_setting_trustt_products_synthese_note'] ) && array_key_exists( $input['el_setting_trustt_products_synthese_note'], $this->el_setting_yes_no_data() ) )
        $output['el_setting_trustt_products_synthese_note'] = $input['el_setting_trustt_products_synthese_note'];

        if ( isset( $input['el_setting_trustt_products_synthese_avis'] ) && array_key_exists( $input['el_setting_trustt_products_synthese_avis'], $this->el_setting_yes_no_data() ) )
        $output['el_setting_trustt_products_synthese_avis'] = $input['el_setting_trustt_products_synthese_avis'];

        if ( isset( $input['el_setting_trustt_products_synthese_empty'] ) && array_key_exists( $input['el_setting_trustt_products_synthese_empty'], $this->el_setting_yes_no_data() ) )
        $output['el_setting_trustt_products_synthese_empty'] = $input['el_setting_trustt_products_synthese_empty'];

        if ( isset( $input['el_setting_trustt_products_synthese_ldjson'] ) && array_key_exists( $input['el_setting_trustt_products_synthese_ldjson'], $this->el_setting_yes_no_data() ) )
        $output['el_setting_trustt_products_synthese_ldjson'] = $input['el_setting_trustt_products_synthese_ldjson'];


        if ( isset( $input['el_setting_trustt_iframe_avis_ligne'] ) && array_key_exists( $input['el_setting_trustt_iframe_avis_ligne'], $this->el_setting_trustt_iframe_avis_ligne_data() ) )
        $output['el_setting_trustt_iframe_avis_ligne'] = $input['el_setting_trustt_iframe_avis_ligne'];

        if ( isset( $input['el_setting_trustt_iframe_avis_number'] ) && array_key_exists( $input['el_setting_trustt_iframe_avis_number'], $this->el_setting_trustt_iframe_avis_number_data() ) )
        $output['el_setting_trustt_iframe_avis_number'] = $input['el_setting_trustt_iframe_avis_number'];

        if ( isset( $input['el_setting_trustt_products_display_hook'] ) && array_key_exists( $input['el_setting_trustt_products_display_hook'], $this->el_setting_trustt_products_display_hook_data() ) )
        $output['el_setting_trustt_products_display_hook'] = $input['el_setting_trustt_products_display_hook'];

        if ( isset( $input['el_setting_trustt_products_display_customer_hook'] ) ) {
			$output['el_setting_trustt_products_display_customer_hook'] = sanitize_text_field( $input['el_setting_trustt_products_display_customer_hook'] );
		}

        if ( isset( $input['el_setting_trustt_iframe_display_hook'] ) && array_key_exists( $input['el_setting_trustt_iframe_display_hook'], $this->el_setting_trustt_iframe_display_hook_data() ) )
        $output['el_setting_trustt_iframe_display_hook'] = $input['el_setting_trustt_iframe_display_hook'];

        if ( isset( $input['el_setting_trustt_iframe_display_customer_hook'] ) ) {
			$output['el_setting_trustt_iframe_display_customer_hook'] = sanitize_text_field( $input['el_setting_trustt_iframe_display_customer_hook'] );
		}

        if ( isset( $input['el_setting_trustt_iframe_avis_order'] ) && array_key_exists( $input['el_setting_trustt_iframe_avis_order'], $this->el_setting_trustt_iframe_avis_order_data() ) )
        $output['el_setting_trustt_iframe_avis_order'] = $input['el_setting_trustt_iframe_avis_order'];

        if ( isset( $input['el_setting_trustt_iframe_display'] ) && array_key_exists( $input['el_setting_trustt_iframe_display'], $this->el_setting_yes_no_data() ) )
        $output['el_setting_trustt_iframe_display'] = $input['el_setting_trustt_iframe_display'];

        if ( isset( $input['el_setting_trustt_products_display'] ) && array_key_exists( $input['el_setting_trustt_products_display'], $this->el_setting_yes_no_data() ) )
        $output['el_setting_trustt_products_display'] = $input['el_setting_trustt_products_display'];

        if ( isset( $input['el_setting_trustt_preview_display'] ) && array_key_exists( $input['el_setting_trustt_preview_display'], $this->el_setting_yes_no_data() ) )
        $output['el_setting_trustt_preview_display'] = $input['el_setting_trustt_preview_display'];

        if ( isset( $input['el_setting_trustt_status_order'] ) && array_key_exists( $input['el_setting_trustt_status_order'], $this->el_setting_trustt_status_order_data() ) )
        $output['el_setting_trustt_status_order'] = $input['el_setting_trustt_status_order'];

        if ( isset( $input['el_setting_section_trustt_ssl'] ) && array_key_exists( $input['el_setting_section_trustt_ssl'], $this->el_setting_yes_no_data() ) )
        $output['el_setting_section_trustt_ssl'] = $input['el_setting_section_trustt_ssl'];

        if ( ! $hasError ) {
            add_settings_error( "trustt_page_el-trustt", esc_attr("trustt_page_el-trustt"), __('Options sauvegardées', 'trustt'), 'updated' );
        }

        return apply_filters( 'el_config_tab_validate', $output, $input );

    }

    /**
     * Generates the footer for admin pages
     *
     * @param bool       $test       For future dev
     * @param string     $option
     */
    public static function el_admin_footer( $test = true, $option ) {

        if ( ( defined( 'WP_DEBUG' ) && WP_DEBUG === true ) ) {

        if ( $test ) {
        // for future dev
        }
       echo  isset( $input['el_setting_trustt_api_key'] );
        $xdebug = ' ';
            echo '
            <div id="poststuff" class="uk-card uk-card-default uk-card-body uk-box-shadow-medium">
            <div class="postbox uk-margin-top">

                <h3 class="hndle"><span>' . esc_html__( 'Debug Information', 'trustt' ) . '</span></h3>
                <div class="inside">
                    <h4>' . esc_html( __( 'Current option:', 'trustt' ) ) . ' <code class="wpseo-debug">' . $option . '</code></h4>
                    ' . ( ( $xdebug ) ? '' : '<pre>' );
            Trustt_Helper::pr( get_option($option) );
            echo '
                    ' . ( ( $xdebug ) ? '' : '</pre>' ) . '
                </div>
            </div>
            </div><!-- .poststuff -->';
        }

    }

    /**
     * When reset to Default values, buffer the output.
     * Avoid "Cannot modify header information - headers already sent by".
     * To avoid side effects, applied only on 'el-trustt-config' pages.
     *
     * @link    http://stackoverflow.com/questions/7381661/cannot-modify-header-information-headers-already-sent-by-wordpress-issue
     * @since   1.0.0
     */
    public function el_do_output_buffer() {

        global $pagenow;

        if ( $pagenow == 'admin.php') {

        ob_start();

        }

    }
}
