<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://www.trustt.io/
 * @since      1.0.0
 *
 * @package    Trustt
 * @subpackage Trustt/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Trustt
 * @subpackage Trustt/admin/partials/tabs
 * @author     Dimitri Longo <info@elanathemes.fr>
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
// Get wp_options name for config tab.
$option = $this->options_config;

// Elana Custom Fields
$options    = get_option( $option );
$apicheck   = isset( $options['el_setting_trustt_api_key'] );
$apikey     = $apicheck ? $options['el_setting_trustt_api_key'] : '';

if ( $apicheck ) {
	$testttt = Trustt_Admin::get_remote( $apikey =  $apikey );
} else {
	update_option( 'trustt_api_check', 0 );
}

$apicheck = Trustt_Admin::trusttapicheck();

if ( $apicheck ) {
	$label = __( 'API Connecté', 'trustt' );
	$color = 'success';
} else {
	$label= __( 'API Non Connecté', 'trustt' );
	$color = 'danger';
}

$trustt_logo = plugins_url( 'trustt-reviews-woocommerce/admin/images/trustt-logo.svg' );
?>
<style>
	#trustt-general .form-table th {
		width: 260px;
	}
</style>
<?php settings_errors(); ?>
<div id="trustt-general">
	<div class="el-wrap about-wrap el-uk-kit">
		<div class="uk-flex-middle" uk-grid>
			<div class="uk-width-2-3@m">
				<h1 class="uk-text-primary" style="margin: 0;"><?php esc_html_e( 'Trustt Reviews', 'trustt' ); ?></h1>
				<span class="uk-badge"><?php echo $this->version; ?></span>
				<h3 class="uk-text-primary"><?php esc_html_e( 'Réglages API', 'trustt' ); ?></h3>
				<span class="uk-label uk-label-<?php echo $color; ?>"><?php echo $label; ?></span>
			</div><!-- .uk-width -->
			<div class="uk-width-1-3@m">
				<div class="uk-flex uk-flex-top uk-visible@m uk-flex-center@m">
					<img src="<?php echo $trustt_logo; ?>" alt="Trustt Logo" />
				</div><!-- .uk-flex -->
			</div><!-- .uk-width -->
		</div><!-- uk-grid -->

		<?php $this->tabs(); ?>

	    <div class="uk-margin-bottom uk-card uk-card-default uk-card-body uk-box-shadow-medium" id="tab-general">
			<div class="uk-margin uk-grid-match" uk-grid>
				<div class="uk-width-2-3@m">
					<form class="uk-form" id="el-settings-fields-general" method="post" action="options.php">
						<?php settings_fields( 'el-settings-general-group-trustt' ); ?>
						<?php do_settings_sections( 'el-settings-general-group-trustt' ); ?>
							<div class="uk-width-1-2@s uk-flex uk-flex-bottom uk-height-small">
								<button type="submit" name="submit" id="submit" class="uk-button uk-button-primary"><span uk-icon="icon: cloud-upload"></span> <?php esc_html_e('Sauvegarder','trustt'); ?></button>
							</div><!-- .uk-width -->
					</form><!-- .uk-form -->
				</div><!-- .uk-width -->
				<div class="uk-width-1-3@m uk-flex uk-flex-center">
					<div class="uk-flex uk-flex-top uk-visible@m uk-flex-center@m">
						<div uk-alert class="uk-padding-small">
							<div><span uk-icon="icon: warning"></span><span class="uk-h4 uk-text-middle"> <?php esc_html_e( 'Notice', 'trustt' ); ?></span></div>
							<p class="el-text-small"><?php esc_html_e( 'Connectez-vous sur Trustt, puis copier/coller le code d\'activation disponible sur la page paramètres/Installation de la boutique de votre marque.', 'trustt'); ?></p>
						</div>
					</div><!-- .uk-flex -->
					<div class="uk-flex uk-flex-bottom uk-flex-left uk-flex-center@m">
						<form class="uk-form" method="post" action="">
							<button name="reset" id="reset" class="uk-button uk-button-danger uk-padding-small uk-padding-remove-vertical"  type="submit" onclick="return confirm(&quot;<?php _e( 'Cliquer sur OK, pour restaurer les paramètres par défauts, ATTENTION vos paramètres seront perdus.', 'trustt' ); ?>&quot;)"><span uk-icon="icon: refresh"></span> <?php esc_html_e('Restaurer paramamètres','trustt'); ?></button>
						</form><!-- .uk-form -->
					</div><!-- .uk-flex -->
				</div><!-- .uk-width -->
			</div><!-- .uk-grid -->
		</div><!-- #trustt-general -->
	<?php


	// Render wp_debug footer.
	Trustt_Admin_Config::el_admin_footer( $test =  false, $option );

	?>
	</div><!-- .about-wrap -->
</div><!-- #trustt-general -->
<?php
if ( isset( $_POST['reset'] ) ) {

  	// Update options with default values.
  	update_option('el-settings-trustt', $this->el_default_tab_config_options_trustt() );

   	header("Location: admin.php?page=el-trustt-general");
	die;
}
?>
