<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://www.trustt.io/
 * @since      1.0.0
 *
 * @package    Trustt
 * @subpackage Trustt/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Trustt
 * @subpackage Trustt/admin/partials/tabs
 * @author     Dimitri Longo <info@elanathemes.fr>
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
$trustt_logo = plugins_url( 'trustt-reviews-woocommerce/admin/images/trustt-logo.svg' );

$apicheck = Trustt_Admin::trusttapicheck();

if ( $apicheck ) {
	$label= __( 'Vous avez  accès aux ressources Trustt, le module est connecté.', 'trustt' );
	$color = 'success';
} else {
	$label= __( 'Vous n\'avez pas accès aux ressources Trustt, le module n\'est pas connecté, veuillez vérifier votre clé API', 'trustt' );
	$color = 'danger';
}

if ( !is_plugin_active( 'woocommerce/woocommerce.php') ) {

	$label = sprintf( __( 'Attention Woocommerce n\'est pas installé ou activé, rendez-vous sur la page des <strong><a href="%s">Extensions</a></strong>.', 'trustt' ), admin_url( '/plugins.php') );
}

?>
<style>
	#trustt-welcome .about-wrap .uk-width-medium  {
	margin: 0;
	height: auto;
	vertical-align: middle;
	width: 300px;
	}
	#trustt-welcome h4 {
		min-height: 30px;
	}
	#trustt-welcome .about-wrap {
		margin-left: 0;
		margin-right: 20px;
		margin-top: 0;
		margin-bottom: 0;
	}
</style>
<div id="trustt-welcome">
	<div class="el-wrap about-wrap el-uk-kit">
		<div class="uk-flex-middle" uk-grid>
			<div class="uk-width-2-3@m">
				<h1 class="uk-text-primary" style="margin: 0;"><?php esc_html_e( 'Trustt Reviews', 'trustt' ); ?></h1>
				<span class="uk-badge"><?php echo $this->version; ?></span>
			</div><!-- .uk-width -->
			<div class="uk-width-1-3@m">
			</div><!-- .uk-width -->
		</div><!-- uk-grid -->
	    <div class="uk-margin uk-card uk-card-default uk-card-body uk-box-shadow-medium uk-preserve" id="tab-welcome">
			<div class="custom-welcome-panel-content">
				<h3 class="uk-h2 uk-text-left uk-margin-remove-top"><?php _e( 'Trustt : Saas n1 de marketing d’influence, de data et avis authentiques', 'trustt' ); ?></h3>
				<div class="uk-text-left uk-grid" uk-grid="">
					<div class="uk-width-2-3@s">
						<img class="uk-width-medium" src="<?php echo $trustt_logo; ?>" alt="Trustt Logo" />
					</div>
					<div class="uk-width-1-3@s">
						<div uk-alert class="uk-alert-<?php echo $color; ?> uk-padding-small">
							<div><span uk-icon="icon: warning"></span><span class="uk-h4 uk-text-middle uk-text-<?php echo $color; ?>"> <?php esc_html_e( 'Message', 'trustt' ); ?></span></div>
							<p class="el-text-small"><?php echo $label; ?></p>
						</div>
						<?php if ( !is_plugin_active( 'woocommerce/woocommerce.php') ) : ?>
							<div uk-alert class="uk-alert-danger uk-padding-small">
								<h5><span uk-icon="icon: warning"></span><span class="uk-text-middle"> <?php esc_html_e( 'Attention', 'trustt' ); ?></span></h5>
								<p><?php echo $label; ?></p>
							</div>
						<?php  endif; ?>
					</div>
				</div>
				<p class="about-description uk-text-primary"><?php _e( 'Voici quelques liens pour vous aider à démarrer :', "trustt" ); ?></p>
				<div class="uk-child-width-expand@s uk-text-left" uk-grid>
					<div class="welcome-panel-column">
						<h4 class="uk-margin-small uk-text-primary"><?php _e( "Commençons par paramétrer votre API key :", "trustt" ); ?></h4>
						<a class="uk-margin uk-button uk-button-primary uk-text-uppercase" href="admin.php?page=el-trustt-general"><span uk-icon="icon: settings"></span><span class="uk-margin-small-left uk-text-middle"><?php _e( 'Réglages API','trustt' ); ?></span></a>
					</div>
					<div class="welcome-panel-column">
						<h4 class="uk-margin-small uk-text-primary"><?php _e( 'Paramétrons votre e-commerce' ); ?></h4>
						<a class="uk-margin uk-button uk-button-primary uk-text-uppercase" href="admin.php?page=el-trustt-ecommerce"><span uk-icon="icon: cart"></span><span class="uk-margin-small-left uk-text-middle"><?php _e( 'Réglages Ecommerce','trustt' ); ?></span></a>
					</div>
				</div>
			</div><!-- .custom-welcome-panel-content -->
		</div><!-- #tab-welcome -->
	</div><!-- .about-wrap -->
</div><!-- #trustt-welcome -->
