<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://www.trustt.io/
 * @since      1.0.0
 *
 * @package    Trustt
 * @subpackage Trustt/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Trustt
 * @subpackage Trustt/public
 * @author     Dimitri Longo <info@elanathemes.fr>
 */


namespace Trustt;

class Trustt_Public {

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $trustt    The ID of this plugin.
     */
    private $trustt;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string    $trustt       The name of the plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct( $trustt, $version ) {

        $this->trustt = $trustt;
        $this->version = $version;

        $options                            = get_option( 'el-settings-trustt' );
        $el_setting_trustt_products_display = isset( $options['el_setting_trustt_products_display'] );
        $el_setting_trustt_products_display = $el_setting_trustt_products_display ? $options['el_setting_trustt_products_display'] : 1;
        $el_setting_trustt_iframe_display   = isset( $options['el_setting_trustt_iframe_display'] );
        $el_setting_trustt_iframe_display   = $el_setting_trustt_iframe_display ? $options['el_setting_trustt_iframe_display'] : 1;

        if ( $el_setting_trustt_products_display ) {
            $el_setting_trustt_products_display_hook   = isset( $options['el_setting_trustt_products_display_hook'] );
            $el_setting_trustt_products_display_hook   = $el_setting_trustt_products_display_hook ? $options['el_setting_trustt_products_display_hook'] : 'woocommerce_single_product_summary';

            $el_setting_trustt_products_display_customer_hook   = isset( $options['el_setting_trustt_products_display_customer_hook'] );
            $el_setting_trustt_products_display_customer_hook   = $el_setting_trustt_products_display_customer_hook ? $options['el_setting_trustt_products_display_customer_hook'] : 'woocommerce_single_product_summary';

            if ( 'customer_custom_hook' == $el_setting_trustt_products_display_hook ) {
                add_action( $el_setting_trustt_products_display_customer_hook, array( $this, 'trusttbeauty_reviews_product' ), 10 );
            }

            if ( 'customer_custom_hook' != $el_setting_trustt_products_display_hook && 'el_trustt_reviews_shortcode' != $el_setting_trustt_products_display_hook ) {
                add_action( $el_setting_trustt_products_display_hook, array( $this, 'trusttbeauty_reviews_product' ), 10 );
            }

            if ( 'el_trustt_reviews_shortcode' == $el_setting_trustt_products_display_hook ) {
                add_shortcode( 'el_trustt_reviews', array( $this, 'el_trustt_reviews' ) );
            }
        }

        if ( $el_setting_trustt_iframe_display ) {
            $el_setting_trustt_iframe_display_hook   = isset( $options['el_setting_trustt_iframe_display_hook'] );
            $el_setting_trustt_iframe_display_hook   = $el_setting_trustt_iframe_display_hook ? $options['el_setting_trustt_iframe_display_hook'] : 'woocommerce_single_product_summary';

            $el_setting_trustt_iframe_display_customer_hook   = isset( $options['el_setting_trustt_iframe_display_customer_hook'] );
            $el_setting_trustt_iframe_display_customer_hook   = $el_setting_trustt_iframe_display_customer_hook ? $options['el_setting_trustt_iframe_display_customer_hook'] : 'woocommerce_single_product_summary';

            if ( 'customer_custom_hook' == $el_setting_trustt_iframe_display_hook ) {
                add_action( $el_setting_trustt_iframe_display_customer_hook, array( $this, 'trusttbeauty_iframe' ), 10 );
            }

            if ( 'customer_custom_hook' != $el_setting_trustt_iframe_display_hook && 'el_trustt_iframe_shortcode' != $el_setting_trustt_iframe_display_hook ) {

                add_action( $el_setting_trustt_iframe_display_hook, array( $this, 'trusttbeauty_iframe' ), 10 );
            }

            if ( 'el_trustt_iframe_shortcode' == $el_setting_trustt_iframe_display_hook ) {
                add_shortcode( 'el_trustt_iframe', array( $this, 'el_trustt_iframe' ) );
            }
        }

        add_shortcode( 'el_trustt_reviews_page', array( $this, 'el_trustt_reviews_page' ) );

        add_action( 'woocommerce_after_shop_loop_item', array( $this, 'trusttbeauty_reviews_preview' ), 10 );

    }

    /**
     * Display Trustt Shortcode [el_trustt_reviews title="" tag=""]
     *
     * @since    1.0.5
     */
    public function el_trustt_reviews( $atts ) {

        if ( ! is_product() ) {

            $content  = '<div class="woocommerce-error" role="alert">';
            $content .= __( 'Le shortcode Trustt Beauty ne peut être rendu uniquement sur une page produit', 'trustt' );
            $content .= '</div>';

            return $content;
        }

        $title = '';
        $atts  = shortcode_atts(
            array(
                'title' => '',
                'tag'   => 'h1',
            ),
            $atts,
            'el_trustt_reviews'
        );

        if ( ! empty( $atts['title'] ) ) {
            $title = '<' . esc_attr( $atts['tag'] ) . '>' . esc_attr( $atts['title'] ) . '</' . esc_attr( $atts['tag'] ) . '>';
        } else {
            $title = '';
        }

        $data                      = $this->trusttbeauty_get_reviews();
        $el_setting_trustt_api_key = $data[1];
        $product_transient         = get_transient( $data[0] );

        if ( ! $product_transient ) {

            $response_array = $this->trusttbeauty( $el_setting_trustt_api_key );
            $nbreviews      = $response_array['nbReviews'];
            $avgrating      = $response_array['avgRating'];

        } else {
            $nbreviews = $product_transient['nbReviews'];
            $avgrating = $product_transient['avgRating'];

        }
        $content = $this->trusttbeauty_richsnippet_product_shortcode_content( $nbreviews, $avgrating );

        ob_start();
        echo sprintf(
            '<div class="el_trusttbeauty_reviews_product">
			%s
			%s
			</div>
			',
            $title, // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
            $content // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
        );

        return ob_get_clean();

    }

    /**
     * Display Trustt Shortcode [el_trustt_reviews_page id="" title="" tag=""]
     *
     * @since    1.1.2
     */
    public function el_trustt_reviews_page( $atts ) {


        $title = '';
        $atts  = shortcode_atts(
            array(
                'id'    => '',
                'title' => '',
                'tag'   => 'h1',
            ),
            $atts,
            'el_trustt_reviews_page'
        );

        if ( empty( $atts['id'] ) ) {

            $content  = '<div class="woocommerce-error" role="alert">';
            $content .= __( 'Le shortcode Trustt Beauty ne peut être rendu uniquement avec un ID sur cette page', 'trustt' );
            $content .= '</div>';

            return $content;
        }

        if ( ! empty( $atts['title'] ) ) {
            $title = '<' . esc_attr( $atts['tag'] ) . '>' . esc_attr( $atts['title'] ) . '</' . esc_attr( $atts['tag'] ) . '>';
        } else {
            $title = '';
        }

        $data                      = $this->trusttbeauty_get_reviews_by_id($atts['id']);
        $el_setting_trustt_api_key = $data[1];
        $product_transient         = get_transient( $data[0] );

        if ( ! $product_transient ) {

            $response_array = $this->trusttbeauty( $el_setting_trustt_api_key, $atts['id'] );
            $nbreviews      = $response_array['nbReviews'];
            $avgrating      = $response_array['avgRating'];

        } else {
            $nbreviews = $product_transient['nbReviews'];
            $avgrating = $product_transient['avgRating'];

        }
        $content = $this->trusttbeauty_richsnippet_preview_shortcode_content( $nbreviews, $avgrating, $atts['id']);

        ob_start();
        echo sprintf(
            '<div class="el_trusttbeauty_reviews_product">
			%s
			%s
			</div>
			',
            $title, // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
            $content // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
        );

        return ob_get_clean();

    }

    /**
     * Display Trustt Shortcode [el_trustt_iframe title="" tag=""]
     *
     * @since    1.0.5
     */
    public function el_trustt_iframe( $atts ) {

        if ( ! is_product() ) {

            $content  = '<div class="woocommerce-error" role="alert">';
            $content .= __( 'Le shortcode Trustt Beauty ne peut être rendu uniquement sur une page produit', 'trustt' );
            $content .= '</div>';

            return $content;
        }

        $title = '';
        $atts  = shortcode_atts(
            array(
                'title' => '',
                'tag'   => 'h1',
            ),
            $atts,
            'el_trustt_iframe'
        );

        if ( ! empty( $atts['title'] ) ) {
            $title = '<' . esc_attr( $atts['tag'] ) . '>' . esc_attr( $atts['title'] ) . '</' . esc_attr( $atts['tag'] ) . '>';
        } else {
            $title = '';
        }

        $content = $this->trusttbeauty_iframe();

        ob_start();
        echo sprintf(
            '<div class="el_trusttbeauty_reviews_product">
			%s
			%s
			</div>
			',
            $title, // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
            $content // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
        );

        return ob_get_clean();

    }
    /**
     * Display Trustt Richsnippets
     *
     * @since    1.0.0
     */
    public function trusttbeauty_richsnippet_preview( $nbreviews, $avgrating ) {

        $apicheck = get_option( 'trustt_api_check' );
        //$apicheck = 0;

        $options                           = get_option( 'el-settings-trustt' );
        $el_setting_trustt_api_key         = isset( $options['el_setting_trustt_api_key'] );
        $el_setting_trustt_api_key         = $el_setting_trustt_api_key ? $options['el_setting_trustt_api_key'] : '';
        $plugin_public_img_url             = WC_TRUSTT_PLUGIN_URL . 'public/images/';
        $el_setting_trustt_preview_avis    = isset( $options['el_setting_trustt_preview_avis'] );
        $el_setting_trustt_preview_avis    = $el_setting_trustt_preview_avis ? $options['el_setting_trustt_preview_avis'] : 1;
        $el_setting_trustt_preview_note    = isset( $options['el_setting_trustt_preview_note'] );
        $el_setting_trustt_preview_note    = $el_setting_trustt_preview_note ? $options['el_setting_trustt_preview_note'] : 1;
        $el_setting_trustt_preview_empty         = isset( $options['el_setting_trustt_preview_empty'] );
        $el_setting_trustt_preview_empty         = $el_setting_trustt_preview_empty ? $options['el_setting_trustt_preview_empty'] : 1;
        $el_setting_trustt_preview_display = isset( $options['el_setting_trustt_preview_display'] );
        $el_setting_trustt_preview_display = $el_setting_trustt_preview_display ? $options['el_setting_trustt_preview_display'] : 1;
        $el_setting_trustt_iframe_display  = isset( $options['el_setting_trustt_iframe_display'] );
        $el_setting_trustt_iframe_display  = $el_setting_trustt_iframe_display ? $options['el_setting_trustt_iframe_display'] : 1;

        if ( $apicheck ) {

            global $product;

            $ranormalizerating = $this->normalizerating100( $avgrating );
            $imagefileurl      = $plugin_public_img_url . 'stars-' . $ranormalizerating . '.svg';
            $imageclass        = 'rating5-sm-r' . $ranormalizerating . '';

            echo '<div class="trustbeautyreviews-product-extrablock">';

            if( $nbreviews === 0 & !$el_setting_trustt_preview_empty ):

            else:

                if ( $nbreviews >= 1 ) :
                    $text = sprintf(
                    /* translators: %s: Count reviews */
                        _n( '%s avis', '%s avis', $nbreviews, 'trustt' ),
                        $nbreviews
                    );
                else :
                    $text = sprintf(
                    /* translators: %s: Count reviews */
                        __( '%s avis', 'trustt' ),
                        $nbreviews
                    );

                endif;

                ?>

                    <?php if ( $el_setting_trustt_iframe_display ) : ?>
                    <a href="<?php echo $this->notld_link(); ?>#avis-produit">
                        <?php endif; ?>

                        <?php if ( $nbreviews >= 1 && $el_setting_trustt_preview_display ) : ?>
                            <div itemscope itemtype="https://schema.org/Product">
                                <meta itemprop="name" content="<?php echo $product->get_name(); ?>">
                                <div itemprop="aggregateRating" itemscope itemtype="https://schema.org/AggregateRating">
                                    <meta itemprop="itemReviewed" content="<?php echo $product->get_name(); ?>">
                                    <meta itemprop="ratingValue" content="<?php echo $avgrating; ?>">
                                    <meta itemprop="reviewCount" content="<?php echo $nbreviews; ?>">
                                    <meta itemprop="bestRating" content="5">
                                    <meta itemprop="worstRating" content="1">
                                </div>
                                <div itemprop="review" itemscope itemtype="https://schema.org/Review">
                                    <meta itemprop="author" content="https://www.trustt.io">
                                    <meta itemprop="itemReviewed" content="<?php echo $product->get_name(); ?>">
                                </div>
                            </div>
                        <?php endif; ?>

                        <?php if ( $el_setting_trustt_preview_note ) : ?>
                            <div class="<?php echo esc_attr( $imageclass ); ?>">
                                <img src="<?php echo esc_url( $imagefileurl ); ?>" width="84">
                            </div>
                        <?php endif; ?>

                        <?php if ( $el_setting_trustt_preview_avis ) : ?>
                            <div class="nbreviews">(<?php echo $text; ?>)</div>
                        <?php endif; ?>

                        <?php if ( $el_setting_trustt_iframe_display ) : ?>
                    </a>
                <?php endif;

            endif;

            echo '</div>';
        }

    }

    /**
     * Display Trustt Richsnippets
     *
     * @since    1.0.0
     */
    public function trusttbeauty_richsnippet_product( $nbreviews, $avgrating ) {

        $apicheck = get_option( 'trustt_api_check' );
        //$apicheck = 0;

        $options                                  = get_option( 'el-settings-trustt' );
        $el_setting_trustt_api_key                = isset( $options['el_setting_trustt_api_key'] );
        $el_setting_trustt_api_key                = $el_setting_trustt_api_key ? $options['el_setting_trustt_api_key'] : '';
        $plugin_public_img_url                    = WC_TRUSTT_PLUGIN_URL . 'public/images/';
        $el_setting_trustt_products_synthese_avis = isset( $options['el_setting_trustt_products_synthese_avis'] );
        $el_setting_trustt_products_synthese_avis = $el_setting_trustt_products_synthese_avis ? $options['el_setting_trustt_products_synthese_avis'] : 1;
        $el_setting_trustt_products_synthese_note = isset( $options['el_setting_trustt_products_synthese_note'] );
        $el_setting_trustt_products_synthese_note = $el_setting_trustt_products_synthese_note ? $options['el_setting_trustt_products_synthese_note'] : 1;
        $el_setting_trustt_products_synthese_empty = isset( $options['el_setting_trustt_products_synthese_empty'] );
        $el_setting_trustt_products_synthese_empty = $el_setting_trustt_products_synthese_empty ? $options['el_setting_trustt_products_synthese_empty'] : 1;
        $el_setting_trustt_products_display       = isset( $options['el_setting_trustt_products_display'] );
        $el_setting_trustt_products_display       = $el_setting_trustt_products_display ? $options['el_setting_trustt_products_display'] : 1;
        $el_setting_trustt_iframe_display         = isset( $options['el_setting_trustt_iframe_display'] );
        $el_setting_trustt_iframe_display         = $el_setting_trustt_iframe_display ? $options['el_setting_trustt_iframe_display'] : 1;
        $el_setting_trustt_products_synthese_ldjson   = isset( $options['el_setting_trustt_products_synthese_ldjson'] );
        $el_setting_trustt_products_synthese_ldjson   = $el_setting_trustt_products_synthese_ldjson ? $options['el_setting_trustt_products_synthese_ldjson'] : 0;

        if ( $apicheck ) {

            if($el_setting_trustt_products_synthese_ldjson === "1") {
                add_filter( 'woocommerce_structured_data_product', array($this, 'trusttbeauty_richsnippet_ldjson'), 10, 2 );
            }

            global $product;

            $ranormalizerating = $this->normalizerating100( $avgrating );
            $imagefileurl      = $plugin_public_img_url . 'stars-' . $ranormalizerating . '.svg';
            $imageclass        = 'rating5-sm-r' . $ranormalizerating . '';

            echo '<div class="trustbeautyreviews-product-extrablock">';

            if($nbreviews === 0 & !$el_setting_trustt_products_synthese_empty):

                if ( $el_setting_trustt_iframe_display ) :
            ?>

                <a href="<?php echo $this->notld_link(); ?>#avis-produit">
                    <?= __( 'Soyez le 1er à déposer un avis', 'trustt' ) ?>
                </a>
            <?php
                endif;

            else:
                if ( $nbreviews >= 1 ) :
                    $text = sprintf(
                    /* translators: %s: Count reviews */
                        _n( '%s avis', '%s avis', $nbreviews, 'trustt' ),
                        $nbreviews
                    );
                else :
                    $text = sprintf(
                    /* translators: %s: Count reviews */
                        __( '%s avis', 'trustt' ),
                        $nbreviews
                    );

                endif;
                ?>

                    <?php if ( $el_setting_trustt_iframe_display ) : ?>
                        <a href="<?php echo $this->notld_link(); ?>#avis-produit">
                    <?php endif; ?>

                        <?php if ( $nbreviews >= 1 && $el_setting_trustt_products_display && is_product() && $el_setting_trustt_products_synthese_ldjson === "0" ) : ?>
                            <div itemscope itemtype="https://schema.org/Product">
                                <meta itemprop="name" content="<?php echo $product->get_name(); ?>">
                                <div itemprop="aggregateRating" itemscope itemtype="https://schema.org/AggregateRating">
                                    <meta itemprop="itemReviewed" content="<?php echo $product->get_name(); ?>">
                                    <meta itemprop="ratingValue" content="<?php echo $avgrating; ?>">
                                    <meta itemprop="reviewCount" content="<?php echo $nbreviews; ?>">
                                    <meta itemprop="bestRating" content="5">
                                    <meta itemprop="worstRating" content="1">
                                </div>
                                <div itemprop="review" itemscope itemtype="https://schema.org/Review">
                                    <meta itemprop="author" content="https://www.trustt.io">
                                    <meta itemprop="itemReviewed" content="<?php echo $product->get_name(); ?>">
                                </div>
                            </div>
                        <?php endif; ?>

                        <?php if ( $el_setting_trustt_products_synthese_note && is_product() ) : ?>
                            <div class="<?php echo esc_attr( $imageclass ); ?>">
                                <img src="<?php echo esc_url( $imagefileurl ); ?>" width="84">
                            </div>
                        <?php endif; ?>

                        <?php if ( $el_setting_trustt_products_synthese_avis && is_product() ) : ?>
                            <div class="nbreviews">(<?php echo $text; ?>)</div>
                        <?php endif; ?>

                <?php if ( $el_setting_trustt_iframe_display ) : ?>
                    </a>
                <?php endif; ?>

            <?php
            endif;

            echo '</div>';
        }

    }

    /**
     * Get product url with or without end trailing slash in order to get anchor works through pages
     *
     * @since    1.0.0
     */
    public function notld_link() {

        global $product;

        $url = get_permalink( $product->get_id() );

        if ( is_product() ) {

            return $url;

        } else {
            return untrailingslashit( $url );
        }
    }

    /**
     * Get Product from Transient unique name and get it
     *
     * @since    1.0.0
     */
    public function trusttbeauty_get_reviews() {

        $options                   = get_option( 'el-settings-trustt' );
        $el_setting_trustt_api_key = isset( $options['el_setting_trustt_api_key'] );
        $el_setting_trustt_api_key = $el_setting_trustt_api_key ? $options['el_setting_trustt_api_key'] : '';

        global $product;

        $defaults = array(
            'api_key'    => $el_setting_trustt_api_key,
            'id_product' => $product->get_id(),
            'iso_code'   => $this->langiso(),
            'id_shop'    => 1,
        );

        $trustt_endpoint = 'https://' . TRUSTT_API_ENDPOINT . '/api/reviews_product_stats';
        $parameters      = array_merge( $defaults );
        $url             = add_query_arg( $parameters, $trustt_endpoint );
        $productid       = $product->get_id();
        $transient_name  = 'trustt_id_' . $productid . '_' . md5( $url );

        //delete_transient($transient_name); // test purpose
        $product_transient = get_transient( $transient_name );

        $data = array( $transient_name, $el_setting_trustt_api_key );

        return $data;

    }


    /**
     * Get Product from Transient unique name and get it
     *
     * @since    1.0.0
     */
    public function trusttbeauty_get_reviews_by_id($produt_ID) {

        $options                   = get_option( 'el-settings-trustt' );
        $el_setting_trustt_api_key = isset( $options['el_setting_trustt_api_key'] );
        $el_setting_trustt_api_key = $el_setting_trustt_api_key ? $options['el_setting_trustt_api_key'] : '';

        global $product;

        $defaults = array(
            'api_key'    => $el_setting_trustt_api_key,
            'id_product' => $produt_ID,
            'iso_code'   => $this->langiso(),
            'id_shop'    => 1,
        );

        $trustt_endpoint = 'https://' . TRUSTT_API_ENDPOINT . '/api/reviews_product_stats';
        $parameters      = array_merge( $defaults );
        $url             = add_query_arg( $parameters, $trustt_endpoint );
        $productid       = $produt_ID;
        $transient_name  = 'trustt_id_' . $productid . '_' . md5( $url );

        //delete_transient($transient_name); // test purpose
        $product_transient = get_transient( $transient_name );

        $data = array( $transient_name, $el_setting_trustt_api_key );

        return $data;

    }

    /**
     * Get Product reviews from transient or not -> Product Page (not product in loop)
     *
     * @since    1.0.0
     */
    public function trusttbeauty_reviews_product() {

        $data                      = $this->trusttbeauty_get_reviews();
        $el_setting_trustt_api_key = $data[1];
        $product_transient         = get_transient( $data[0] );

        if ( ! $product_transient ) {

            $response_array = $this->trusttbeauty( $el_setting_trustt_api_key );
            $nbreviews      = $response_array['nbReviews'];
            $avgrating      = $response_array['avgRating'];
            return $this->trusttbeauty_richsnippet_product( $nbreviews, $avgrating );

        } else {
            $nbreviews = $product_transient['nbReviews'];
            $avgrating = $product_transient['avgRating'];

            return $this->trusttbeauty_richsnippet_product( $nbreviews, $avgrating );
        }

    }

    /**
     * Get Product reviews from transient or not -> Product Preview (products in loop)
     *
     * @since    1.0.0
     */
    public function trusttbeauty_reviews_preview() {

        $data                      = $this->trusttbeauty_get_reviews();
        $el_setting_trustt_api_key = $data[1];
        $product_transient         = get_transient( $data[0] );

        if ( ! $product_transient ) {

            $response_array = $this->trusttbeauty( $el_setting_trustt_api_key );
            $nbreviews      = $response_array['nbReviews'];
            $avgrating      = $response_array['avgRating'];
            return $this->trusttbeauty_richsnippet_preview( $nbreviews, $avgrating );

        } else {
            $nbreviews = $product_transient['nbReviews'];
            $avgrating = $product_transient['avgRating'];

            return $this->trusttbeauty_richsnippet_preview( $nbreviews, $avgrating );
        }

    }

    /**
     * get normalize rating from $avgrating
     *
     * @since    1.0.0
     */
    public static function normalizerating100( $avgrating ) {
        return 100 * ( round( $avgrating * 4 ) / 4 );
    }

    /**
     * Create Transient (24 Hours) from Trustt API CALL
     *
     * @since    1.0.0
     */
    public function trusttbeauty( $apikey, $produt_ID = null ) {

        $apicheck                      = get_option( 'trustt_api_check' );
        $options                       = get_option( 'el-settings-trustt' );
        $el_setting_trustt_api_key     = isset( $options['el_setting_trustt_api_key'] );
        $el_setting_trustt_api_key     = $el_setting_trustt_api_key ? $options['el_setting_trustt_api_key'] : '';
        $el_setting_section_trustt_ssl = isset( $options['el_setting_section_trustt_ssl'] );
        $el_setting_section_trustt_ssl = $el_setting_section_trustt_ssl ? $options['el_setting_section_trustt_ssl'] : 0;
        $transient                     = get_transient( 'css_t_subscribers' );

        if ( $apicheck ) {

            if( $produt_ID ) {
                $product = wc_get_product($produt_ID);
            }
            else {
                global $product;
                $produt_ID = $product->get_id();
            }

            $defaults = array(
                'api_key'    => $el_setting_trustt_api_key,
                'id_product' => $produt_ID,
                'iso_code'   => $this->langiso(),
                'id_shop'    => 1,
            );

            if ( $el_setting_section_trustt_ssl ) {
                $args_for_get = array(
                    'sslverify' => true,
                );
            } else {
                $args_for_get = array(
                    'sslverify' => false,
                );
            }

            $trustt_endpoint = 'https://' . TRUSTT_API_ENDPOINT . '/api/reviews_product_stats';

            $parameters = array_merge( $defaults );
            $url        = add_query_arg( $parameters, $trustt_endpoint );
            $response   = wp_remote_get( $url, $args_for_get );

            $response_body = wp_remote_retrieve_body( $response );

            $details = json_decode( $response_body, true );

            //setting transient unique name
            $productid = $product->get_id();
            $transient_name = 'trustt_id_' . $productid . '_' . md5( $url );

            //setting the cache using the WP Transient API (24 hours)
            set_transient( $transient_name, $details, 24 * HOUR_IN_SECONDS );

            return json_decode( $response_body, true );

        }
    }

    /**
     * Display Trustt beauty Iframe
     *
     * @since    1.0.0
     */
    public function trusttbeauty_iframe() {

        $apicheck = get_option( 'trustt_api_check' );
        //$apicheck = 0;

        $options                               = get_option( 'el-settings-trustt' );
        $el_setting_trustt_api_key             = isset( $options['el_setting_trustt_api_key'] );
        $el_setting_trustt_iframe_avis_ligne   = isset( $options['el_setting_trustt_iframe_avis_ligne'] );
        $el_setting_trustt_iframe_avis_number  = isset( $options['el_setting_trustt_iframe_avis_number'] );
        $el_setting_trustt_iframe_avis_order   = isset( $options['el_setting_trustt_iframe_avis_order'] );
        $el_setting_trustt_iframe_avis_ligne   = $el_setting_trustt_iframe_avis_ligne ? $options['el_setting_trustt_iframe_avis_ligne'] : 2;
        $el_setting_trustt_iframe_avis_number  = $el_setting_trustt_iframe_avis_number ? $options['el_setting_trustt_iframe_avis_number'] : 6;
        $el_setting_trustt_iframe_avis_order   = $el_setting_trustt_iframe_avis_order ? $options['el_setting_trustt_iframe_avis_order'] : 'date_desc';
        $el_setting_trustt_api_key             = $el_setting_trustt_api_key ? $options['el_setting_trustt_api_key'] : '';
        $el_setting_trustt_iframe_display_hook = isset( $options['el_setting_trustt_iframe_display_hook'] );
        $el_setting_trustt_iframe_display_hook = $el_setting_trustt_iframe_display_hook ? $options['el_setting_trustt_iframe_display_hook'] : 'woocommerce_single_product_summary';

        if ( $apicheck ) {

            global $product;
            $content  = '<div id="trustbeauty_review_thread"></div>';
            $content .= '<a name="avis-produit"></a>';
            $content .= '<script>';
            $content .= '
				var trustbeauty_config = {
					apiKey : \'' . $el_setting_trustt_api_key . '\',
					productId : \'' . $product->get_id() . '\',
					lang : \'' . $this->langiso() . '\',
					nbCols : \'' . $el_setting_trustt_iframe_avis_ligne . '\',
					nbReviews : \'' . $el_setting_trustt_iframe_avis_number . '\',
					order : \'' . $el_setting_trustt_iframe_avis_order . '\',

				};
				(function() {
					var d = document, s = d.createElement(\'script\');
						s.src = \'https://app.trustt.io/static/js/embed/trustbeauty-review.min.js\';
						s.setAttribute(\'data-timestamp\', +new Date());
						(d.head || d.body).appendChild(s);
					})();
				';
            $content .= '</script>';
            $content .= '<noscript>Merci d\'activer Javascript pour afficher les avis produit</noscript>';

            if ( 'el_trustt_iframe_shortcode' == $el_setting_trustt_iframe_display_hook ) {

                return $content;

            } else {

                echo $content;// phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
            }
        }

    }

    /**
     * Register the stylesheets for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_styles() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Trustt_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Trustt_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        $min = $this->ifdebug();

        wp_register_style( 'el-trustt-public', plugin_dir_url( __FILE__ ) . 'css/trustt-public' . $min . 'css', array(), time(), 'all' );
        wp_enqueue_style( 'el-trustt-public' );

    }

    /**
     * Register the JavaScript for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Trustt_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Trustt_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        $min = $this->ifdebug();

    }

    /**
     *  Check if wp_debug is TRUE
     *
     * @since 1.0.0
     */
    private function ifdebug() {

        if ( WP_DEBUG ) {
            $min = '.';
        } else {
            $min = '.min.';
        }
        return $min;
    }


    /**
     *  Get Blog info language ISO
     *
     * @since 1.0.0
     */
    private function langiso() {

        $lang = substr( get_bloginfo( 'language' ), 0, 2 );

        return $lang;
    }

    /**
     * Get Trustt Richsnippets content for shortcode
     *
     * @since 1.0.0
     */
    public function trusttbeauty_richsnippet_product_shortcode_content( $nbreviews, $avgrating ) {

        $apicheck = get_option( 'trustt_api_check' );

        $options                                  = get_option( 'el-settings-trustt' );
        $el_setting_trustt_api_key                = isset( $options['el_setting_trustt_api_key'] );
        $el_setting_trustt_api_key                = $el_setting_trustt_api_key ? $options['el_setting_trustt_api_key'] : '';
        $plugin_public_img_url                    = WC_TRUSTT_PLUGIN_URL . 'public/images/';
        $el_setting_trustt_products_synthese_avis = isset( $options['el_setting_trustt_products_synthese_avis'] );
        $el_setting_trustt_products_synthese_avis = $el_setting_trustt_products_synthese_avis ? $options['el_setting_trustt_products_synthese_avis'] : 1;
        $el_setting_trustt_products_synthese_note = isset( $options['el_setting_trustt_products_synthese_note'] );
        $el_setting_trustt_products_synthese_note = $el_setting_trustt_products_synthese_note ? $options['el_setting_trustt_products_synthese_note'] : 1;
        $el_setting_trustt_products_synthese_empty = isset( $options['el_setting_trustt_products_synthese_empty'] );
        $el_setting_trustt_products_synthese_empty = $el_setting_trustt_products_synthese_empty ? $options['el_setting_trustt_products_synthese_empty'] : 1;
        $el_setting_trustt_products_display       = isset( $options['el_setting_trustt_products_display'] );
        $el_setting_trustt_products_display       = $el_setting_trustt_products_display ? $options['el_setting_trustt_products_display'] : 1;
        $el_setting_trustt_iframe_display         = isset( $options['el_setting_trustt_iframe_display'] );
        $el_setting_trustt_iframe_display         = $el_setting_trustt_iframe_display ? $options['el_setting_trustt_iframe_display'] : 1;
        $el_setting_trustt_products_synthese_ldjson   = isset( $options['el_setting_trustt_products_synthese_ldjson'] );
        $el_setting_trustt_products_synthese_ldjson   = $el_setting_trustt_products_synthese_ldjson ? $options['el_setting_trustt_products_synthese_ldjson'] : 0;

        if($el_setting_trustt_products_synthese_ldjson === "1") {
            add_filter( 'woocommerce_structured_data_product', array($this, 'trusttbeauty_richsnippet_ldjson'), 10, 2 );
        }

        if ( $apicheck ) {

            global $product;

            $ranormalizerating = $this->normalizerating100( $avgrating );
            $imagefileurl      = $plugin_public_img_url . 'stars-' . $ranormalizerating . '.svg';
            $imageclass        = 'rating5-sm-r' . $ranormalizerating . '';

            $content = '<div class="trustbeautyreviews-product-extrablock">';
            if($nbreviews === 0 & !$el_setting_trustt_products_synthese_empty):

                if ( $el_setting_trustt_iframe_display ) :

                    $content .= '<a href="' . $this->notld_link() .'#avis-produit">';
                    $content .= __( 'Soyez le 1er à déposer un avis', 'trustt' );
                    $content .= '</a>';
                endif;

            else:

                if ( $nbreviews >= 1 ) :
                    $text = sprintf(
                    /* translators: %s: Count reviews */
                        _n( '%s avis', '%s avis', $nbreviews, 'trustt' ),
                        $nbreviews
                    );
                else :
                    $text = sprintf(
                    /* translators: %s: Count reviews */
                        __( '%s avis', 'trustt' ),
                        $nbreviews
                    );

                endif;

                if ( $el_setting_trustt_iframe_display ) :
                    $content .= '<a href="' . $this->notld_link() . '#avis-produit">';
                endif;
                if ( $nbreviews >= 1 && $el_setting_trustt_products_display && is_product() && $el_setting_trustt_products_synthese_ldjson === "0" ) :
                    $content .= '<div itemscope itemtype="https://schema.org/Product">';
                    $content .= '<meta itemprop="name" content="' . $product->get_name() . '">';
                    $content .= '<div itemprop="aggregateRating" itemscope itemtype="https://schema.org/AggregateRating">';
                    $content .= '<meta itemprop="itemReviewed" content="' . $product->get_name() . '">';
                    $content .= '<meta itemprop="ratingValue" content="' . $avgrating . '">';
                    $content .= '<meta itemprop="reviewCount" content="' . $nbreviews . '">';
                    $content .= '<meta itemprop="bestRating" content="5">';
                    $content .= '<meta itemprop="worstRating" content="1">';
                    $content .= '</div>';
                    $content .= '<div itemprop="review" itemscope itemtype="https://schema.org/Review">';
                    $content .= '<meta itemprop="author" content="https://www.trustt.io">';
                    $content .= '<meta itemprop="itemReviewed" content="' . $product->get_name() . '">';
                    $content .= '</div>';
                    $content .= '</div>';
                endif;
                if ( $el_setting_trustt_products_synthese_note && is_product() ) :
                    $content .= '<div class="' . $imageclass . '">';
                    $content .= '<img src="' . $imagefileurl . '" width="84">';
                    $content .= '</div>';
                endif;

                if ( $el_setting_trustt_products_synthese_avis && is_product() ) :
                    $content .= '<div class="nbreviews">(' . $text . ')</div>';
                endif;

                if ( $el_setting_trustt_iframe_display ) :
                    $content .= '</a>';
                endif;

            endif;

            $content .= '</div>';

            return $content;

        }

    }

    /**
     * Get Trustt Richsnippets content for shortcode
     *
     * @since 1.1.2
     */
    public function trusttbeauty_richsnippet_preview_shortcode_content( $nbreviews, $avgrating, $idproduit ) {

        $apicheck = get_option( 'trustt_api_check' );

        $options                                = get_option( 'el-settings-trustt' );
        $el_setting_trustt_api_key              = isset( $options['el_setting_trustt_api_key'] );
        $el_setting_trustt_api_key              = $el_setting_trustt_api_key ? $options['el_setting_trustt_api_key'] : '';
        $plugin_public_img_url                  = WC_TRUSTT_PLUGIN_URL . 'public/images/';
        $el_setting_trustt_preview_avis         = isset( $options['el_setting_trustt_preview_avis'] );
        $el_setting_trustt_preview_avis         = $el_setting_trustt_preview_avis ? $options['el_setting_trustt_preview_avis'] : 1;
        $el_setting_trustt_preview_note         = isset( $options['el_setting_trustt_preview_note'] );
        $el_setting_trustt_preview_note         = $el_setting_trustt_preview_note ? $options['el_setting_trustt_preview_note'] : 1;
        $el_setting_trustt_preview_empty         = isset( $options['el_setting_trustt_preview_empty'] );
        $el_setting_trustt_preview_empty         = $el_setting_trustt_preview_empty ? $options['el_setting_trustt_preview_empty'] : 1;
        $el_setting_trustt_preview_display      = isset( $options['el_setting_trustt_preview_display'] );
        $el_setting_trustt_preview_display      = $el_setting_trustt_preview_display ? $options['el_setting_trustt_preview_display'] : 1;
        $el_setting_trustt_iframe_display       = isset( $options['el_setting_trustt_iframe_display'] );
        $el_setting_trustt_iframe_display       = $el_setting_trustt_iframe_display ? $options['el_setting_trustt_iframe_display'] : 1;

        if ( $apicheck ) {

            if($idproduit) {
                $product = wc_get_product($idproduit);
            } else {
                global $product;
            }

            $content = '<div class="trustbeautyreviews-product-extrablock">';

            if($nbreviews === 0 & !$el_setting_trustt_preview_empty):

            else:
                $ranormalizerating = $this->normalizerating100( $avgrating );
                $imagefileurl      = $plugin_public_img_url . 'stars-' . $ranormalizerating . '.svg';
                $imageclass        = 'rating5-sm-r' . $ranormalizerating . '';

                if ( $nbreviews >= 1 ) :
                    $text = sprintf(
                    /* translators: %s: Count reviews */
                        _n( '%s avis', '%s avis', $nbreviews, 'trustt' ),
                        $nbreviews
                    );
                else :
                    $text = sprintf(
                    /* translators: %s: Count reviews */
                        __( '%s avis', 'trustt' ),
                        $nbreviews
                    );

                endif;

                if ( $nbreviews >= 1 && $el_setting_trustt_preview_display ) :
                    $content .= '<div itemscope itemtype="https://schema.org/Product">';
                    $content .= '<meta itemprop="name" content="' . $product->get_name() . '">';
                    $content .= '<div itemprop="aggregateRating" itemscope itemtype="https://schema.org/AggregateRating">';
                    $content .= '<meta itemprop="itemReviewed" content="' . $product->get_name() . '">';
                    $content .= '<meta itemprop="ratingValue" content="' . $avgrating . '">';
                    $content .= '<meta itemprop="reviewCount" content="' . $nbreviews . '">';
                    $content .= '<meta itemprop="bestRating" content="5">';
                    $content .= '<meta itemprop="worstRating" content="1">';
                    $content .= '</div>';
                    $content .= '<div itemprop="review" itemscope itemtype="https://schema.org/Review">';
                    $content .= '<meta itemprop="author" content="https://www.trustt.io">';
                    $content .= '<meta itemprop="itemReviewed" content="' . $product->get_name() . '">';
                    $content .= '</div>';
                    $content .= '</div>';
                endif;
                if ( $el_setting_trustt_preview_note ) :
                    $content .= '<div class="' . $imageclass . '">';
                    $content .= '<img src="' . $imagefileurl . '" width="84">';
                    $content .= '</div>';
                endif;

                if ( $el_setting_trustt_preview_avis ) :
                    $content .= '<div class="nbreviews">(' . $text . ')</div>';
                endif;

            endif;

            $content .= '</div>';

            return $content;

        }

    }

    public function trusttbeauty_richsnippet_ldjson($markup, $product) {

        $data                      = $this->trusttbeauty_get_reviews();
        $el_setting_trustt_api_key = $data[1];
        $product_transient         = get_transient( $data[0] );

        if ( ! $product_transient ) {

            $response_array = $this->trusttbeauty( $el_setting_trustt_api_key, $atts['id'] );
            $nbreviews      = $response_array['nbReviews'];
            $avgrating      = $response_array['avgRating'];

        } else {
            $nbreviews = $product_transient['nbReviews'];
            $avgrating = $product_transient['avgRating'];

        }

        $markup['aggregateRating'] = array(
            '@type'       => 'AggregateRating',
            'ratingValue' => $avgrating,
            'reviewCount' => $nbreviews,
        );
        unset($markup['review']);
        return $markup;

    }

}
