<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://www.trustt.io/
 * @since             1.0.0
 * @package           Trustt
 *
 * @wordpress-plugin
 * Plugin Name:       Trustt Reviews Woocommerce
 * Plugin URI:        https://www.trustt.io/
 * Description:       Trustt Reviews vous permet de récolter des avis sur vos produits. Affichez-les pour rassurer vos visiteurs et augmentez le panier d'achat moyen.
 * Version:           1.2.0
 * Author:            Trustt
 * Author URI:        https://www.trustt.io/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       trustt
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'TRUSTT_VERSION', '1.2.0' );

/**
 * Currently json order version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'TRUSTT_VERSION_JSON_ORDERS', '1.0.0' );

/**
 * Trustt API ENDPOINT URL constant
 *
 * @since    1.0.5
 */
define( 'TRUSTT_API_ENDPOINT', 'app.trustt.io' );

/**
 * Plugin URL constant
 *
 * @since    1.0.0
 */
define( 'WC_TRUSTT_PLUGIN_URL', plugin_dir_url( __FILE__ ) );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-trustt-activator.php
 */
function activate_trustt() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-trustt-activator.php';
	trustt_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-trustt-deactivator.php
 */
function deactivate_trustt() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-trustt-deactivator.php';
	trustt_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_trustt' );
register_deactivation_hook( __FILE__, 'deactivate_trustt' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-trustt.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_trustt() {

	$plugin = new trustt();
	$plugin->run();

}
run_trustt();
