<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Widget base.
 *
 * @package Trustt
 * @since 1.0.0
 */
class Trustt_Widget extends WP_Widget {

	/**
	 * Widget CSS class.
	 *
	 * @var string
	 */
	public $widget_cssclass;

	/**
	 * Widget description.
	 *
	 * @var string
	 */
	public $widget_description;

	/**
	 * Widget id.
	 *
	 * @var string
	 */
	//public $widget_id;

	/**
	 * Widget name.
	 *
	 * @var string
	 */
	public $widget_name;

	/**
	 * Widget settings.
	 *
	 * @var array
	 */
	public $settings;

	public $widget_id 		= 'widget_trustt';
	/**
	 * Constructor.
	 */
	public function __construct() {
		$this->register();
	}

	/**
	 * Registers widget.
	 */
	public function register() {

		$this->widget_cssclass    = 'trustt';
		$this->widget_description = __( 'Widget Trustt.', 'trustt' );
		$this->widget_id          = 'widget_trustt';
		$this->widget_name        = $this->widget_name;

		$widget_ops = array(
			'classname'   => $this->widget_cssclass,
			'description' => $this->widget_description,
		);

		parent::__construct( $this->widget_id, $this->widget_name, $widget_ops );

		add_action( 'save_post', array( $this, 'flush_widget_cache' ) );
		add_action( 'deleted_post', array( $this, 'flush_widget_cache' ) );
		add_action( 'switch_theme', array( $this, 'flush_widget_cache' ) );
	}

	/**
	 * Checks for cached version of widget and outputs it if found.
	 *
	 * @param array $args
	 * @return bool
	 */
	public function get_cached_widget( $args ) {
		$cache = wp_cache_get( $this->widget_id, 'widget' );

		if ( ! is_array( $cache ) ) {
			$cache = array();
		}

		if ( isset( $cache[ $args['widget_id'] ] ) ) {
			echo $cache[ $args['widget_id'] ];
			return true;
		}

		return false;
	}

	/**
	 * Caches the widget.
	 *
	 * @param array  $args
	 * @param string $content
	 */
	public function cache_widget( $args, $content ) {

		$cache[ $args['widget_id'] ] = $content;

		wp_cache_set( $this->widget_id, $cache, 'widget' );
	}

	/**
	 * Flushes the cache for a widget.
	 */
	public function flush_widget_cache() {
		wp_cache_delete( $this->widget_id, 'widget' );
	}

	/**
	 * Updates a widget instance settings.
	 *
	 * @see WP_Widget->update
	 * @param array $new_instance
	 * @param array $old_instance
	 * @return array
	 */
	public function update( $new_instance, $old_instance ) {
		$instance              = $old_instance;
		$instance              = array();
		$instance[ 'title' ]   = ( ! empty( $new_instance[ 'title' ] ) ) ? strip_tags( $new_instance['title'] ) : '';
		$instance[ 'status' ]  = strip_tags ( $new_instance[ 'status' ] );
		$instance[ 'postnum' ] = strip_tags ( $new_instance[ 'postnum' ] );

		$this->flush_widget_cache();

		return $instance;
	}

	/**
	 * Displays widget setup form.
	 *
	 * @see WP_Widget->form
	 * @param array $instance
	 * @return void
	 */
	public function form( $instance ) {

		// TODO: Define default values for your variables
		$instance = wp_parse_args(
			(array) $instance
		);

		if ( isset( $instance[ 'title' ] ) ) {

			$title          = $instance[ 'title' ];

		} else {

			$title          	= __( 'New title', 'trustt' );

		}
		// Display the admin form
		include( plugin_dir_path( __FILE__ )  . 'views/admin.php');

	}

	/**
	 * Echoes the widget content.
	 *
	 * @see    WP_Widget
	 *
	 * @param array $args
	 * @param array $instance
	 */
	public function widget( $args, $instance ) {}
}
